/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│vi: set net ft=c ts=2 sts=2 sw=2 fenc=utf-8                                :vi│
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2020 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/str/str.h"

/**
 * Returns nonzero if c is lowercase letter.
 */
int iswlower(wint_t c) {
  if (isascii(c)) return islower(c);
  switch (c) {
    case u'µ':    // MICRO SIGN (0x00b5)
    case u'ß':    // LATIN SMALL SHARP S (0x00df)
    case u'à':    // LATIN SMALL A W/ GRAVE (0x00e0)
    case u'á':    // LATIN SMALL A W/ ACUTE (0x00e1)
    case u'â':    // LATIN SMALL A W/ CIRCUMFLEX (0x00e2)
    case u'ã':    // LATIN SMALL A W/ TILDE (0x00e3)
    case u'ä':    // LATIN SMALL A W/ DIAERESIS (0x00e4)
    case u'å':    // LATIN SMALL A W/ RING ABOVE (0x00e5)
    case u'æ':    // LATIN SMALL AE (0x00e6)
    case u'ç':    // LATIN SMALL C W/ CEDILLA (0x00e7)
    case u'è':    // LATIN SMALL E W/ GRAVE (0x00e8)
    case u'é':    // LATIN SMALL E W/ ACUTE (0x00e9)
    case u'ê':    // LATIN SMALL E W/ CIRCUMFLEX (0x00ea)
    case u'ë':    // LATIN SMALL E W/ DIAERESIS (0x00eb)
    case u'ì':    // LATIN SMALL I W/ GRAVE (0x00ec)
    case u'í':    // LATIN SMALL I W/ ACUTE (0x00ed)
    case u'î':    // LATIN SMALL I W/ CIRCUMFLEX (0x00ee)
    case u'ï':    // LATIN SMALL I W/ DIAERESIS (0x00ef)
    case u'ð':    // LATIN SMALL ETH (0x00f0)
    case u'ñ':    // LATIN SMALL N W/ TILDE (0x00f1)
    case u'ò':    // LATIN SMALL O W/ GRAVE (0x00f2)
    case u'ó':    // LATIN SMALL O W/ ACUTE (0x00f3)
    case u'ô':    // LATIN SMALL O W/ CIRCUMFLEX (0x00f4)
    case u'õ':    // LATIN SMALL O W/ TILDE (0x00f5)
    case u'ö':    // LATIN SMALL O W/ DIAERESIS (0x00f6)
    case u'ø':    // LATIN SMALL O W/ STROKE (0x00f8)
    case u'ù':    // LATIN SMALL U W/ GRAVE (0x00f9)
    case u'ú':    // LATIN SMALL U W/ ACUTE (0x00fa)
    case u'û':    // LATIN SMALL U W/ CIRCUMFLEX (0x00fb)
    case u'ü':    // LATIN SMALL U W/ DIAERESIS (0x00fc)
    case u'ý':    // LATIN SMALL Y W/ ACUTE (0x00fd)
    case u'þ':    // LATIN SMALL THORN (0x00fe)
    case u'ÿ':    // LATIN SMALL Y W/ DIAERESIS (0x00ff)
    case u'ā':    // LATIN SMALL A W/ MACRON (0x0101)
    case u'ă':    // LATIN SMALL A W/ BREVE (0x0103)
    case u'ą':    // LATIN SMALL A W/ OGONEK (0x0105)
    case u'ć':    // LATIN SMALL C W/ ACUTE (0x0107)
    case u'ĉ':    // LATIN SMALL C W/ CIRCUMFLEX (0x0109)
    case u'ċ':    // LATIN SMALL C W/ DOT ABOVE (0x010b)
    case u'č':    // LATIN SMALL C W/ CARON (0x010d)
    case u'ď':    // LATIN SMALL D W/ CARON (0x010f)
    case u'đ':    // LATIN SMALL D W/ STROKE (0x0111)
    case u'ē':    // LATIN SMALL E W/ MACRON (0x0113)
    case u'ĕ':    // LATIN SMALL E W/ BREVE (0x0115)
    case u'ė':    // LATIN SMALL E W/ DOT ABOVE (0x0117)
    case u'ę':    // LATIN SMALL E W/ OGONEK (0x0119)
    case u'ě':    // LATIN SMALL E W/ CARON (0x011b)
    case u'ĝ':    // LATIN SMALL G W/ CIRCUMFLEX (0x011d)
    case u'ğ':    // LATIN SMALL G W/ BREVE (0x011f)
    case u'ġ':    // LATIN SMALL G W/ DOT ABOVE (0x0121)
    case u'ģ':    // LATIN SMALL G W/ CEDILLA (0x0123)
    case u'ĥ':    // LATIN SMALL H W/ CIRCUMFLEX (0x0125)
    case u'ħ':    // LATIN SMALL H W/ STROKE (0x0127)
    case u'ĩ':    // LATIN SMALL I W/ TILDE (0x0129)
    case u'ī':    // LATIN SMALL I W/ MACRON (0x012b)
    case u'ĭ':    // LATIN SMALL I W/ BREVE (0x012d)
    case u'į':    // LATIN SMALL I W/ OGONEK (0x012f)
    case u'ı':    // LATIN SMALL DOTLESS I (0x0131)
    case u'ĳ':    // LATIN SMALL LIGATURE IJ (0x0133)
    case u'ĵ':    // LATIN SMALL J W/ CIRCUMFLEX (0x0135)
    case u'ķ':    // LATIN SMALL K W/ CEDILLA (0x0137)
    case u'ĸ':    // LATIN SMALL KRA (0x0138)
    case u'ĺ':    // LATIN SMALL L W/ ACUTE (0x013a)
    case u'ļ':    // LATIN SMALL L W/ CEDILLA (0x013c)
    case u'ľ':    // LATIN SMALL L W/ CARON (0x013e)
    case u'ŀ':    // LATIN SMALL L W/ MIDDLE DOT (0x0140)
    case u'ł':    // LATIN SMALL L W/ STROKE (0x0142)
    case u'ń':    // LATIN SMALL N W/ ACUTE (0x0144)
    case u'ņ':    // LATIN SMALL N W/ CEDILLA (0x0146)
    case u'ň':    // LATIN SMALL N W/ CARON (0x0148)
    case u'ŉ':    // LATIN SMALL N PRECEDED BY APOSTROPHE (0x0149)
    case u'ŋ':    // LATIN SMALL ENG (0x014b)
    case u'ō':    // LATIN SMALL O W/ MACRON (0x014d)
    case u'ŏ':    // LATIN SMALL O W/ BREVE (0x014f)
    case u'ő':    // LATIN SMALL O W/ DOUBLE ACUTE (0x0151)
    case u'œ':    // LATIN SMALL LIGATURE OE (0x0153)
    case u'ŕ':    // LATIN SMALL R W/ ACUTE (0x0155)
    case u'ŗ':    // LATIN SMALL R W/ CEDILLA (0x0157)
    case u'ř':    // LATIN SMALL R W/ CARON (0x0159)
    case u'ś':    // LATIN SMALL S W/ ACUTE (0x015b)
    case u'ŝ':    // LATIN SMALL S W/ CIRCUMFLEX (0x015d)
    case u'ş':    // LATIN SMALL S W/ CEDILLA (0x015f)
    case u'š':    // LATIN SMALL S W/ CARON (0x0161)
    case u'ţ':    // LATIN SMALL T W/ CEDILLA (0x0163)
    case u'ť':    // LATIN SMALL T W/ CARON (0x0165)
    case u'ŧ':    // LATIN SMALL T W/ STROKE (0x0167)
    case u'ũ':    // LATIN SMALL U W/ TILDE (0x0169)
    case u'ū':    // LATIN SMALL U W/ MACRON (0x016b)
    case u'ŭ':    // LATIN SMALL U W/ BREVE (0x016d)
    case u'ů':    // LATIN SMALL U W/ RING ABOVE (0x016f)
    case u'ű':    // LATIN SMALL U W/ DOUBLE ACUTE (0x0171)
    case u'ų':    // LATIN SMALL U W/ OGONEK (0x0173)
    case u'ŵ':    // LATIN SMALL W W/ CIRCUMFLEX (0x0175)
    case u'ŷ':    // LATIN SMALL Y W/ CIRCUMFLEX (0x0177)
    case u'ź':    // LATIN SMALL Z W/ ACUTE (0x017a)
    case u'ż':    // LATIN SMALL Z W/ DOT ABOVE (0x017c)
    case u'ž':    // LATIN SMALL Z W/ CARON (0x017e)
    case u'ſ':    // LATIN SMALL LONG S (0x017f)
    case u'ƀ':    // LATIN SMALL B W/ STROKE (0x0180)
    case u'ƃ':    // LATIN SMALL B W/ TOPBAR (0x0183)
    case u'ƅ':    // LATIN SMALL TONE SIX (0x0185)
    case u'ƈ':    // LATIN SMALL C W/ HOOK (0x0188)
    case u'ƌ':    // LATIN SMALL D W/ TOPBAR (0x018c)
    case u'ƍ':    // LATIN SMALL TURNED DELTA (0x018d)
    case u'ƒ':    // LATIN SMALL F W/ HOOK (0x0192)
    case u'ƕ':    // LATIN SMALL HV (0x0195)
    case u'ƙ':    // LATIN SMALL K W/ HOOK (0x0199)
    case u'ƚ':    // LATIN SMALL L W/ BAR (0x019a)
    case u'ƛ':    // LATIN SMALL LAMBDA W/ STROKE (0x019b)
    case u'ƞ':    // LATIN SMALL N W/ LONG RIGHT LEG (0x019e)
    case u'ơ':    // LATIN SMALL O W/ HORN (0x01a1)
    case u'ƣ':    // LATIN SMALL OI (0x01a3)
    case u'ƥ':    // LATIN SMALL P W/ HOOK (0x01a5)
    case u'ƨ':    // LATIN SMALL TONE TWO (0x01a8)
    case u'ƪ':    // LATIN LETTER REVERSED ESH LOOP (0x01aa)
    case u'ƫ':    // LATIN SMALL T W/ PALATAL HOOK (0x01ab)
    case u'ƭ':    // LATIN SMALL T W/ HOOK (0x01ad)
    case u'ư':    // LATIN SMALL U W/ HORN (0x01b0)
    case u'ƴ':    // LATIN SMALL Y W/ HOOK (0x01b4)
    case u'ƶ':    // LATIN SMALL Z W/ STROKE (0x01b6)
    case u'ƹ':    // LATIN SMALL EZH REVERSED (0x01b9)
    case u'ƺ':    // LATIN SMALL EZH W/ TAIL (0x01ba)
    case u'ƽ':    // LATIN SMALL TONE FIVE (0x01bd)
    case u'ƾ':    // LATIN LETTER INVERTED GLOTTAL STOP W/ STROKE (0x01be)
    case u'ƿ':    // LATIN LETTER WYNN (0x01bf)
    case u'ǆ':    // LATIN SMALL DZ W/ CARON (0x01c6)
    case u'ǉ':    // LATIN SMALL LJ (0x01c9)
    case u'ǌ':    // LATIN SMALL NJ (0x01cc)
    case u'ǎ':    // LATIN SMALL A W/ CARON (0x01ce)
    case u'ǐ':    // LATIN SMALL I W/ CARON (0x01d0)
    case u'ǒ':    // LATIN SMALL O W/ CARON (0x01d2)
    case u'ǔ':    // LATIN SMALL U W/ CARON (0x01d4)
    case u'ǖ':    // LATIN SMALL U W/ DIAERESIS AND MACRON (0x01d6)
    case u'ǘ':    // LATIN SMALL U W/ DIAERESIS AND ACUTE (0x01d8)
    case u'ǚ':    // LATIN SMALL U W/ DIAERESIS AND CARON (0x01da)
    case u'ǜ':    // LATIN SMALL U W/ DIAERESIS AND GRAVE (0x01dc)
    case u'ǝ':    // LATIN SMALL TURNED E (0x01dd)
    case u'ǟ':    // LATIN SMALL A W/ DIAERESIS AND MACRON (0x01df)
    case u'ǡ':    // LATIN SMALL A W/ DOT ABOVE AND MACRON (0x01e1)
    case u'ǣ':    // LATIN SMALL AE W/ MACRON (0x01e3)
    case u'ǥ':    // LATIN SMALL G W/ STROKE (0x01e5)
    case u'ǧ':    // LATIN SMALL G W/ CARON (0x01e7)
    case u'ǩ':    // LATIN SMALL K W/ CARON (0x01e9)
    case u'ǫ':    // LATIN SMALL O W/ OGONEK (0x01eb)
    case u'ǭ':    // LATIN SMALL O W/ OGONEK AND MACRON (0x01ed)
    case u'ǯ':    // LATIN SMALL EZH W/ CARON (0x01ef)
    case u'ǰ':    // LATIN SMALL J W/ CARON (0x01f0)
    case u'ǳ':    // LATIN SMALL DZ (0x01f3)
    case u'ǵ':    // LATIN SMALL G W/ ACUTE (0x01f5)
    case u'ǹ':    // LATIN SMALL N W/ GRAVE (0x01f9)
    case u'ǻ':    // LATIN SMALL A W/ RING ABOVE AND ACUTE (0x01fb)
    case u'ǽ':    // LATIN SMALL AE W/ ACUTE (0x01fd)
    case u'ǿ':    // LATIN SMALL O W/ STROKE AND ACUTE (0x01ff)
    case u'ȁ':    // LATIN SMALL A W/ DOUBLE GRAVE (0x0201)
    case u'ȃ':    // LATIN SMALL A W/ INVERTED BREVE (0x0203)
    case u'ȅ':    // LATIN SMALL E W/ DOUBLE GRAVE (0x0205)
    case u'ȇ':    // LATIN SMALL E W/ INVERTED BREVE (0x0207)
    case u'ȉ':    // LATIN SMALL I W/ DOUBLE GRAVE (0x0209)
    case u'ȋ':    // LATIN SMALL I W/ INVERTED BREVE (0x020b)
    case u'ȍ':    // LATIN SMALL O W/ DOUBLE GRAVE (0x020d)
    case u'ȏ':    // LATIN SMALL O W/ INVERTED BREVE (0x020f)
    case u'ȑ':    // LATIN SMALL R W/ DOUBLE GRAVE (0x0211)
    case u'ȓ':    // LATIN SMALL R W/ INVERTED BREVE (0x0213)
    case u'ȕ':    // LATIN SMALL U W/ DOUBLE GRAVE (0x0215)
    case u'ȗ':    // LATIN SMALL U W/ INVERTED BREVE (0x0217)
    case u'ș':    // LATIN SMALL S W/ COMMA BELOW (0x0219)
    case u'ț':    // LATIN SMALL T W/ COMMA BELOW (0x021b)
    case u'ȝ':    // LATIN SMALL YOGH (0x021d)
    case u'ȟ':    // LATIN SMALL H W/ CARON (0x021f)
    case u'ȡ':    // LATIN SMALL D W/ CURL (0x0221)
    case u'ȣ':    // LATIN SMALL OU (0x0223)
    case u'ȥ':    // LATIN SMALL Z W/ HOOK (0x0225)
    case u'ȧ':    // LATIN SMALL A W/ DOT ABOVE (0x0227)
    case u'ȩ':    // LATIN SMALL E W/ CEDILLA (0x0229)
    case u'ȫ':    // LATIN SMALL O W/ DIAERESIS AND MACRON (0x022b)
    case u'ȭ':    // LATIN SMALL O W/ TILDE AND MACRON (0x022d)
    case u'ȯ':    // LATIN SMALL O W/ DOT ABOVE (0x022f)
    case u'ȱ':    // LATIN SMALL O W/ DOT ABOVE AND MACRON (0x0231)
    case u'ȳ':    // LATIN SMALL Y W/ MACRON (0x0233)
    case u'ȴ':    // LATIN SMALL L W/ CURL (0x0234)
    case u'ȵ':    // LATIN SMALL N W/ CURL (0x0235)
    case u'ȶ':    // LATIN SMALL T W/ CURL (0x0236)
    case u'ȷ':    // LATIN SMALL DOTLESS J (0x0237)
    case u'ȸ':    // LATIN SMALL DB DIGRAPH (0x0238)
    case u'ȹ':    // LATIN SMALL QP DIGRAPH (0x0239)
    case u'ȼ':    // LATIN SMALL C W/ STROKE (0x023c)
    case u'ȿ':    // LATIN SMALL S W/ SWASH TAIL (0x023f)
    case u'ɀ':    // LATIN SMALL Z W/ SWASH TAIL (0x0240)
    case u'ɂ':    // LATIN SMALL GLOTTAL STOP (0x0242)
    case u'ɇ':    // LATIN SMALL E W/ STROKE (0x0247)
    case u'ɉ':    // LATIN SMALL J W/ STROKE (0x0249)
    case u'ɋ':    // LATIN SMALL Q W/ HOOK TAIL (0x024b)
    case u'ɍ':    // LATIN SMALL R W/ STROKE (0x024d)
    case u'ɏ':    // LATIN SMALL Y W/ STROKE (0x024f)
    case u'ɐ':    // LATIN SMALL TURNED A (0x0250)
    case u'ɑ':    // LATIN SMALL ALPHA (0x0251)
    case u'ɒ':    // LATIN SMALL TURNED ALPHA (0x0252)
    case u'ɓ':    // LATIN SMALL B W/ HOOK (0x0253)
    case u'ɔ':    // LATIN SMALL OPEN O (0x0254)
    case u'ɕ':    // LATIN SMALL C W/ CURL (0x0255)
    case u'ɖ':    // LATIN SMALL D W/ TAIL (0x0256)
    case u'ɗ':    // LATIN SMALL D W/ HOOK (0x0257)
    case u'ɘ':    // LATIN SMALL REVERSED E (0x0258)
    case u'ə':    // LATIN SMALL SCHWA (0x0259)
    case u'ɚ':    // LATIN SMALL SCHWA W/ HOOK (0x025a)
    case u'ɛ':    // LATIN SMALL OPEN E (0x025b)
    case u'ɜ':    // LATIN SMALL REVERSED OPEN E (0x025c)
    case u'ɝ':    // LATIN SMALL REVERSED OPEN E W/ HOOK (0x025d)
    case u'ɞ':    // LATIN SMALL CLOSED REVERSED OPEN E (0x025e)
    case u'ɟ':    // LATIN SMALL DOTLESS J W/ STROKE (0x025f)
    case u'ɠ':    // LATIN SMALL G W/ HOOK (0x0260)
    case u'ɡ':    // LATIN SMALL SCRIPT G (0x0261)
    case u'ɢ':    // LATIN LETTER SMALL CAPITAL G (0x0262)
    case u'ɣ':    // LATIN SMALL GAMMA (0x0263)
    case u'ɤ':    // LATIN SMALL RAMS HORN (0x0264)
    case u'ɥ':    // LATIN SMALL TURNED H (0x0265)
    case u'ɦ':    // LATIN SMALL H W/ HOOK (0x0266)
    case u'ɧ':    // LATIN SMALL HENG W/ HOOK (0x0267)
    case u'ɨ':    // LATIN SMALL I W/ STROKE (0x0268)
    case u'ɩ':    // LATIN SMALL IOTA (0x0269)
    case u'ɪ':    // LATIN LETTER SMALL CAPITAL I (0x026a)
    case u'ɫ':    // LATIN SMALL L W/ MIDDLE TILDE (0x026b)
    case u'ɬ':    // LATIN SMALL L W/ BELT (0x026c)
    case u'ɭ':    // LATIN SMALL L W/ RETROFLEX HOOK (0x026d)
    case u'ɮ':    // LATIN SMALL LEZH (0x026e)
    case u'ɯ':    // LATIN SMALL TURNED M (0x026f)
    case u'ɰ':    // LATIN SMALL TURNED M W/ LONG LEG (0x0270)
    case u'ɱ':    // LATIN SMALL M W/ HOOK (0x0271)
    case u'ɲ':    // LATIN SMALL N W/ LEFT HOOK (0x0272)
    case u'ɳ':    // LATIN SMALL N W/ RETROFLEX HOOK (0x0273)
    case u'ɴ':    // LATIN LETTER SMALL CAPITAL N (0x0274)
    case u'ɵ':    // LATIN SMALL BARRED O (0x0275)
    case u'ɶ':    // LATIN LETTER SMALL CAPITAL OE (0x0276)
    case u'ɷ':    // LATIN SMALL CLOSED OMEGA (0x0277)
    case u'ɸ':    // LATIN SMALL PHI (0x0278)
    case u'ɹ':    // LATIN SMALL TURNED R (0x0279)
    case u'ɺ':    // LATIN SMALL TURNED R W/ LONG LEG (0x027a)
    case u'ɻ':    // LATIN SMALL TURNED R W/ HOOK (0x027b)
    case u'ɼ':    // LATIN SMALL R W/ LONG LEG (0x027c)
    case u'ɽ':    // LATIN SMALL R W/ TAIL (0x027d)
    case u'ɾ':    // LATIN SMALL R W/ FISHHOOK (0x027e)
    case u'ɿ':    // LATIN SMALL REVERSED R W/ FISHHOOK (0x027f)
    case u'ʀ':    // LATIN LETTER SMALL CAPITAL R (0x0280)
    case u'ʁ':    // LATIN LETTER SMALL CAPITAL INVERTED R (0x0281)
    case u'ʂ':    // LATIN SMALL S W/ HOOK (0x0282)
    case u'ʃ':    // LATIN SMALL ESH (0x0283)
    case u'ʄ':    // LATIN SMALL DOTLESS J W/ STROKE AND HOOK (0x0284)
    case u'ʅ':    // LATIN SMALL SQUAT REVERSED ESH (0x0285)
    case u'ʆ':    // LATIN SMALL ESH W/ CURL (0x0286)
    case u'ʇ':    // LATIN SMALL TURNED T (0x0287)
    case u'ʈ':    // LATIN SMALL T W/ RETROFLEX HOOK (0x0288)
    case u'ʉ':    // LATIN SMALL U BAR (0x0289)
    case u'ʊ':    // LATIN SMALL UPSILON (0x028a)
    case u'ʋ':    // LATIN SMALL V W/ HOOK (0x028b)
    case u'ʌ':    // LATIN SMALL TURNED V (0x028c)
    case u'ʍ':    // LATIN SMALL TURNED W (0x028d)
    case u'ʎ':    // LATIN SMALL TURNED Y (0x028e)
    case u'ʏ':    // LATIN LETTER SMALL CAPITAL Y (0x028f)
    case u'ʐ':    // LATIN SMALL Z W/ RETROFLEX HOOK (0x0290)
    case u'ʑ':    // LATIN SMALL Z W/ CURL (0x0291)
    case u'ʒ':    // LATIN SMALL EZH (0x0292)
    case u'ʓ':    // LATIN SMALL EZH W/ CURL (0x0293)
    case u'ʕ':    // LATIN LETTER PHARYNGEAL VOICED FRICATIVE (0x0295)
    case u'ʖ':    // LATIN LETTER INVERTED GLOTTAL STOP (0x0296)
    case u'ʗ':    // LATIN LETTER STRETCHED C (0x0297)
    case u'ʘ':    // LATIN LETTER BILABIAL CLICK (0x0298)
    case u'ʙ':    // LATIN LETTER SMALL CAPITAL B (0x0299)
    case u'ʚ':    // LATIN SMALL CLOSED OPEN E (0x029a)
    case u'ʛ':    // LATIN LETTER SMALL CAPITAL G W/ HOOK (0x029b)
    case u'ʜ':    // LATIN LETTER SMALL CAPITAL H (0x029c)
    case u'ʝ':    // LATIN SMALL J W/ CROSSED-TAIL (0x029d)
    case u'ʞ':    // LATIN SMALL TURNED K (0x029e)
    case u'ʟ':    // LATIN LETTER SMALL CAPITAL L (0x029f)
    case u'ʠ':    // LATIN SMALL Q W/ HOOK (0x02a0)
    case u'ʡ':    // LATIN LETTER GLOTTAL STOP W/ STROKE (0x02a1)
    case u'ʢ':    // LATIN LETTER REVERSED GLOTTAL STOP W/ STROKE (0x02a2)
    case u'ʣ':    // LATIN SMALL DZ DIGRAPH (0x02a3)
    case u'ʤ':    // LATIN SMALL DEZH DIGRAPH (0x02a4)
    case u'ʥ':    // LATIN SMALL DZ DIGRAPH W/ CURL (0x02a5)
    case u'ʦ':    // LATIN SMALL TS DIGRAPH (0x02a6)
    case u'ʧ':    // LATIN SMALL TESH DIGRAPH (0x02a7)
    case u'ʨ':    // LATIN SMALL TC DIGRAPH W/ CURL (0x02a8)
    case u'ʩ':    // LATIN SMALL FENG DIGRAPH (0x02a9)
    case u'ʪ':    // LATIN SMALL LS DIGRAPH (0x02aa)
    case u'ʫ':    // LATIN SMALL LZ DIGRAPH (0x02ab)
    case u'ʬ':    // LATIN LETTER BILABIAL PERCUSSIVE (0x02ac)
    case u'ʭ':    // LATIN LETTER BIDENTAL PERCUSSIVE (0x02ad)
    case u'ʮ':    // LATIN SMALL TURNED H W/ FISHHOOK (0x02ae)
    case u'ʯ':    // LATIN SMALL TURNED H W/ FISHHOOK AND TAIL (0x02af)
    case u'ͱ':    // GREEK SMALL HETA (0x0371)
    case u'ͳ':    // GREEK SMALL ARCHAIC SAMPI (0x0373)
    case u'ͷ':    // GREEK SMALL PAMPHYLIAN DIGAMMA (0x0377)
    case u'ͻ':    // GREEK SMALL REVERSED LUNATE SIGMA SYMBOL (0x037b)
    case u'ͼ':    // GREEK SMALL DOTTED LUNATE SIGMA SYMBOL (0x037c)
    case u'ͽ':    // GREEK SMALL REVERSED DOTTED LUNATE SIGMA SYMBOL (0x037d)
    case u'ΐ':    // GREEK SMALL IOTA W/ DIALYTIKA AND TONOS (0x0390)
    case u'ά':    // GREEK SMALL ALPHA W/ TONOS (0x03ac)
    case u'έ':    // GREEK SMALL EPSILON W/ TONOS (0x03ad)
    case u'ή':    // GREEK SMALL ETA W/ TONOS (0x03ae)
    case u'ί':    // GREEK SMALL IOTA W/ TONOS (0x03af)
    case u'ΰ':    // GREEK SMALL UPSILON W/ DIALYTIKA AND TONOS (0x03b0)
    case u'α':    // GREEK SMALL ALPHA (0x03b1)
    case u'β':    // GREEK SMALL BETA (0x03b2)
    case u'γ':    // GREEK SMALL GAMMA (0x03b3)
    case u'δ':    // GREEK SMALL DELTA (0x03b4)
    case u'ε':    // GREEK SMALL EPSILON (0x03b5)
    case u'ζ':    // GREEK SMALL ZETA (0x03b6)
    case u'η':    // GREEK SMALL ETA (0x03b7)
    case u'θ':    // GREEK SMALL THETA (0x03b8)
    case u'ι':    // GREEK SMALL IOTA (0x03b9)
    case u'κ':    // GREEK SMALL KAPPA (0x03ba)
    case u'λ':    // GREEK SMALL LAMDA (0x03bb)
    case u'μ':    // GREEK SMALL MU (0x03bc)
    case u'ν':    // GREEK SMALL NU (0x03bd)
    case u'ξ':    // GREEK SMALL XI (0x03be)
    case u'ο':    // GREEK SMALL OMICRON (0x03bf)
    case u'π':    // GREEK SMALL PI (0x03c0)
    case u'ρ':    // GREEK SMALL RHO (0x03c1)
    case u'ς':    // GREEK SMALL FINAL SIGMA (0x03c2)
    case u'σ':    // GREEK SMALL SIGMA (0x03c3)
    case u'τ':    // GREEK SMALL TAU (0x03c4)
    case u'υ':    // GREEK SMALL UPSILON (0x03c5)
    case u'φ':    // GREEK SMALL PHI (0x03c6)
    case u'χ':    // GREEK SMALL CHI (0x03c7)
    case u'ψ':    // GREEK SMALL PSI (0x03c8)
    case u'ω':    // GREEK SMALL OMEGA (0x03c9)
    case u'ϊ':    // GREEK SMALL IOTA W/ DIALYTIKA (0x03ca)
    case u'ϋ':    // GREEK SMALL UPSILON W/ DIALYTIKA (0x03cb)
    case u'ό':    // GREEK SMALL OMICRON W/ TONOS (0x03cc)
    case u'ύ':    // GREEK SMALL UPSILON W/ TONOS (0x03cd)
    case u'ώ':    // GREEK SMALL OMEGA W/ TONOS (0x03ce)
    case u'ϐ':    // GREEK BETA SYMBOL (0x03d0)
    case u'ϑ':    // GREEK THETA SYMBOL (0x03d1)
    case u'ϕ':    // GREEK PHI SYMBOL (0x03d5)
    case u'ϖ':    // GREEK PI SYMBOL (0x03d6)
    case u'ϗ':    // GREEK KAI SYMBOL (0x03d7)
    case u'ϙ':    // GREEK SMALL ARCHAIC KOPPA (0x03d9)
    case u'ϛ':    // GREEK SMALL STIGMA (0x03db)
    case u'ϝ':    // GREEK SMALL DIGAMMA (0x03dd)
    case u'ϟ':    // GREEK SMALL KOPPA (0x03df)
    case u'ϡ':    // GREEK SMALL SAMPI (0x03e1)
    case u'ϣ':    // COPTIC SMALL SHEI (0x03e3)
    case u'ϥ':    // COPTIC SMALL FEI (0x03e5)
    case u'ϧ':    // COPTIC SMALL KHEI (0x03e7)
    case u'ϩ':    // COPTIC SMALL HORI (0x03e9)
    case u'ϫ':    // COPTIC SMALL GANGIA (0x03eb)
    case u'ϭ':    // COPTIC SMALL SHIMA (0x03ed)
    case u'ϯ':    // COPTIC SMALL DEI (0x03ef)
    case u'ϰ':    // GREEK KAPPA SYMBOL (0x03f0)
    case u'ϱ':    // GREEK RHO SYMBOL (0x03f1)
    case u'ϲ':    // GREEK LUNATE SIGMA SYMBOL (0x03f2)
    case u'ϳ':    // GREEK LETTER YOT (0x03f3)
    case u'ϵ':    // GREEK LUNATE EPSILON SYMBOL (0x03f5)
    case u'ϸ':    // GREEK SMALL SHO (0x03f8)
    case u'ϻ':    // GREEK SMALL SAN (0x03fb)
    case u'ϼ':    // GREEK RHO W/ STROKE SYMBOL (0x03fc)
    case u'а':    // CYRILLIC SMALL A (0x0430)
    case u'б':    // CYRILLIC SMALL BE (0x0431)
    case u'в':    // CYRILLIC SMALL VE (0x0432)
    case u'г':    // CYRILLIC SMALL GHE (0x0433)
    case u'д':    // CYRILLIC SMALL DE (0x0434)
    case u'е':    // CYRILLIC SMALL IE (0x0435)
    case u'ж':    // CYRILLIC SMALL ZHE (0x0436)
    case u'з':    // CYRILLIC SMALL ZE (0x0437)
    case u'и':    // CYRILLIC SMALL I (0x0438)
    case u'й':    // CYRILLIC SMALL SHORT I (0x0439)
    case u'к':    // CYRILLIC SMALL KA (0x043a)
    case u'л':    // CYRILLIC SMALL EL (0x043b)
    case u'м':    // CYRILLIC SMALL EM (0x043c)
    case u'н':    // CYRILLIC SMALL EN (0x043d)
    case u'о':    // CYRILLIC SMALL O (0x043e)
    case u'п':    // CYRILLIC SMALL PE (0x043f)
    case u'р':    // CYRILLIC SMALL ER (0x0440)
    case u'с':    // CYRILLIC SMALL ES (0x0441)
    case u'т':    // CYRILLIC SMALL TE (0x0442)
    case u'у':    // CYRILLIC SMALL U (0x0443)
    case u'ф':    // CYRILLIC SMALL EF (0x0444)
    case u'х':    // CYRILLIC SMALL HA (0x0445)
    case u'ц':    // CYRILLIC SMALL TSE (0x0446)
    case u'ч':    // CYRILLIC SMALL CHE (0x0447)
    case u'ш':    // CYRILLIC SMALL SHA (0x0448)
    case u'щ':    // CYRILLIC SMALL SHCHA (0x0449)
    case u'ъ':    // CYRILLIC SMALL HARD SIGN (0x044a)
    case u'ы':    // CYRILLIC SMALL YERU (0x044b)
    case u'ь':    // CYRILLIC SMALL SOFT SIGN (0x044c)
    case u'э':    // CYRILLIC SMALL E (0x044d)
    case u'ю':    // CYRILLIC SMALL YU (0x044e)
    case u'я':    // CYRILLIC SMALL YA (0x044f)
    case u'ѐ':    // CYRILLIC SMALL IE W/ GRAVE (0x0450)
    case u'ё':    // CYRILLIC SMALL IO (0x0451)
    case u'ђ':    // CYRILLIC SMALL DJE (0x0452)
    case u'ѓ':    // CYRILLIC SMALL GJE (0x0453)
    case u'є':    // CYRILLIC SMALL UKRAINIAN IE (0x0454)
    case u'ѕ':    // CYRILLIC SMALL DZE (0x0455)
    case u'і':    // CYRILLIC SMALL BYELORUSSIAN-UKRAINIAN I (0x0456)
    case u'ї':    // CYRILLIC SMALL YI (0x0457)
    case u'ј':    // CYRILLIC SMALL JE (0x0458)
    case u'љ':    // CYRILLIC SMALL LJE (0x0459)
    case u'њ':    // CYRILLIC SMALL NJE (0x045a)
    case u'ћ':    // CYRILLIC SMALL TSHE (0x045b)
    case u'ќ':    // CYRILLIC SMALL KJE (0x045c)
    case u'ѝ':    // CYRILLIC SMALL I W/ GRAVE (0x045d)
    case u'ў':    // CYRILLIC SMALL SHORT U (0x045e)
    case u'џ':    // CYRILLIC SMALL DZHE (0x045f)
    case u'ѡ':    // CYRILLIC SMALL OMEGA (0x0461)
    case u'ѣ':    // CYRILLIC SMALL YAT (0x0463)
    case u'ѥ':    // CYRILLIC SMALL IOTIFIED E (0x0465)
    case u'ѧ':    // CYRILLIC SMALL LITTLE YUS (0x0467)
    case u'ѩ':    // CYRILLIC SMALL IOTIFIED LITTLE YUS (0x0469)
    case u'ѫ':    // CYRILLIC SMALL BIG YUS (0x046b)
    case u'ѭ':    // CYRILLIC SMALL IOTIFIED BIG YUS (0x046d)
    case u'ѯ':    // CYRILLIC SMALL KSI (0x046f)
    case u'ѱ':    // CYRILLIC SMALL PSI (0x0471)
    case u'ѳ':    // CYRILLIC SMALL FITA (0x0473)
    case u'ѵ':    // CYRILLIC SMALL IZHITSA (0x0475)
    case u'ѷ':    // CYRILLIC SMALL IZHITSA W/ DOUBLE GRAVE ACCENT (0x0477)
    case u'ѹ':    // CYRILLIC SMALL UK (0x0479)
    case u'ѻ':    // CYRILLIC SMALL ROUND OMEGA (0x047b)
    case u'ѽ':    // CYRILLIC SMALL OMEGA W/ TITLO (0x047d)
    case u'ѿ':    // CYRILLIC SMALL OT (0x047f)
    case u'ҁ':    // CYRILLIC SMALL KOPPA (0x0481)
    case u'ҋ':    // CYRILLIC SMALL SHORT I W/ TAIL (0x048b)
    case u'ҍ':    // CYRILLIC SMALL SEMISOFT SIGN (0x048d)
    case u'ҏ':    // CYRILLIC SMALL ER W/ TICK (0x048f)
    case u'ґ':    // CYRILLIC SMALL GHE W/ UPTURN (0x0491)
    case u'ғ':    // CYRILLIC SMALL GHE W/ STROKE (0x0493)
    case u'ҕ':    // CYRILLIC SMALL GHE W/ MIDDLE HOOK (0x0495)
    case u'җ':    // CYRILLIC SMALL ZHE W/ DESCENDER (0x0497)
    case u'ҙ':    // CYRILLIC SMALL ZE W/ DESCENDER (0x0499)
    case u'қ':    // CYRILLIC SMALL KA W/ DESCENDER (0x049b)
    case u'ҝ':    // CYRILLIC SMALL KA W/ VERTICAL STROKE (0x049d)
    case u'ҟ':    // CYRILLIC SMALL KA W/ STROKE (0x049f)
    case u'ҡ':    // CYRILLIC SMALL BASHKIR KA (0x04a1)
    case u'ң':    // CYRILLIC SMALL EN W/ DESCENDER (0x04a3)
    case u'ҥ':    // CYRILLIC SMALL LIGATURE EN GHE (0x04a5)
    case u'ҧ':    // CYRILLIC SMALL PE W/ MIDDLE HOOK (0x04a7)
    case u'ҩ':    // CYRILLIC SMALL ABKHASIAN HA (0x04a9)
    case u'ҫ':    // CYRILLIC SMALL ES W/ DESCENDER (0x04ab)
    case u'ҭ':    // CYRILLIC SMALL TE W/ DESCENDER (0x04ad)
    case u'ү':    // CYRILLIC SMALL STRAIGHT U (0x04af)
    case u'ұ':    // CYRILLIC SMALL STRAIGHT U W/ STROKE (0x04b1)
    case u'ҳ':    // CYRILLIC SMALL HA W/ DESCENDER (0x04b3)
    case u'ҵ':    // CYRILLIC SMALL LIGATURE TE TSE (0x04b5)
    case u'ҷ':    // CYRILLIC SMALL CHE W/ DESCENDER (0x04b7)
    case u'ҹ':    // CYRILLIC SMALL CHE W/ VERTICAL STROKE (0x04b9)
    case u'һ':    // CYRILLIC SMALL SHHA (0x04bb)
    case u'ҽ':    // CYRILLIC SMALL ABKHASIAN CHE (0x04bd)
    case u'ҿ':    // CYRILLIC SMALL ABKHASIAN CHE W/ DESCENDER (0x04bf)
    case u'ӂ':    // CYRILLIC SMALL ZHE W/ BREVE (0x04c2)
    case u'ӄ':    // CYRILLIC SMALL KA W/ HOOK (0x04c4)
    case u'ӆ':    // CYRILLIC SMALL EL W/ TAIL (0x04c6)
    case u'ӈ':    // CYRILLIC SMALL EN W/ HOOK (0x04c8)
    case u'ӊ':    // CYRILLIC SMALL EN W/ TAIL (0x04ca)
    case u'ӌ':    // CYRILLIC SMALL KHAKASSIAN CHE (0x04cc)
    case u'ӎ':    // CYRILLIC SMALL EM W/ TAIL (0x04ce)
    case u'ӏ':    // CYRILLIC SMALL PALOCHKA (0x04cf)
    case u'ӑ':    // CYRILLIC SMALL A W/ BREVE (0x04d1)
    case u'ӓ':    // CYRILLIC SMALL A W/ DIAERESIS (0x04d3)
    case u'ӕ':    // CYRILLIC SMALL LIGATURE A IE (0x04d5)
    case u'ӗ':    // CYRILLIC SMALL IE W/ BREVE (0x04d7)
    case u'ә':    // CYRILLIC SMALL SCHWA (0x04d9)
    case u'ӛ':    // CYRILLIC SMALL SCHWA W/ DIAERESIS (0x04db)
    case u'ӝ':    // CYRILLIC SMALL ZHE W/ DIAERESIS (0x04dd)
    case u'ӟ':    // CYRILLIC SMALL ZE W/ DIAERESIS (0x04df)
    case u'ӡ':    // CYRILLIC SMALL ABKHASIAN DZE (0x04e1)
    case u'ӣ':    // CYRILLIC SMALL I W/ MACRON (0x04e3)
    case u'ӥ':    // CYRILLIC SMALL I W/ DIAERESIS (0x04e5)
    case u'ӧ':    // CYRILLIC SMALL O W/ DIAERESIS (0x04e7)
    case u'ө':    // CYRILLIC SMALL BARRED O (0x04e9)
    case u'ӫ':    // CYRILLIC SMALL BARRED O W/ DIAERESIS (0x04eb)
    case u'ӭ':    // CYRILLIC SMALL E W/ DIAERESIS (0x04ed)
    case u'ӯ':    // CYRILLIC SMALL U W/ MACRON (0x04ef)
    case u'ӱ':    // CYRILLIC SMALL U W/ DIAERESIS (0x04f1)
    case u'ӳ':    // CYRILLIC SMALL U W/ DOUBLE ACUTE (0x04f3)
    case u'ӵ':    // CYRILLIC SMALL CHE W/ DIAERESIS (0x04f5)
    case u'ӷ':    // CYRILLIC SMALL GHE W/ DESCENDER (0x04f7)
    case u'ӹ':    // CYRILLIC SMALL YERU W/ DIAERESIS (0x04f9)
    case u'ӻ':    // CYRILLIC SMALL GHE W/ STROKE AND HOOK (0x04fb)
    case u'ӽ':    // CYRILLIC SMALL HA W/ HOOK (0x04fd)
    case u'ӿ':    // CYRILLIC SMALL HA W/ STROKE (0x04ff)
    case u'ԁ':    // CYRILLIC SMALL KOMI DE (0x0501)
    case u'ԃ':    // CYRILLIC SMALL KOMI DJE (0x0503)
    case u'ԅ':    // CYRILLIC SMALL KOMI ZJE (0x0505)
    case u'ԇ':    // CYRILLIC SMALL KOMI DZJE (0x0507)
    case u'ԉ':    // CYRILLIC SMALL KOMI LJE (0x0509)
    case u'ԋ':    // CYRILLIC SMALL KOMI NJE (0x050b)
    case u'ԍ':    // CYRILLIC SMALL KOMI SJE (0x050d)
    case u'ԏ':    // CYRILLIC SMALL KOMI TJE (0x050f)
    case u'ԑ':    // CYRILLIC SMALL REVERSED ZE (0x0511)
    case u'ԓ':    // CYRILLIC SMALL EL W/ HOOK (0x0513)
    case u'ԕ':    // CYRILLIC SMALL LHA (0x0515)
    case u'ԗ':    // CYRILLIC SMALL RHA (0x0517)
    case u'ԙ':    // CYRILLIC SMALL YAE (0x0519)
    case u'ԛ':    // CYRILLIC SMALL QA (0x051b)
    case u'ԝ':    // CYRILLIC SMALL WE (0x051d)
    case u'ԟ':    // CYRILLIC SMALL ALEUT KA (0x051f)
    case u'ԡ':    // CYRILLIC SMALL EL W/ MIDDLE HOOK (0x0521)
    case u'ԣ':    // CYRILLIC SMALL EN W/ MIDDLE HOOK (0x0523)
    case u'ԥ':    // CYRILLIC SMALL PE W/ DESCENDER (0x0525)
    case u'ԧ':    // CYRILLIC SMALL SHHA W/ DESCENDER (0x0527)
    case u'ԩ':   // CYRILLIC SMALL EN W/ LEFT HOOK (0x0529)
    case u'ԫ':   // CYRILLIC SMALL DZZHE (0x052b)
    case u'ԭ':   // CYRILLIC SMALL DCHE (0x052d)
    case u'ԯ':   // CYRILLIC SMALL EL W/ DESCENDER (0x052f)
    case u'ՠ':   // ARMENIAN SMALL TURNED AYB (0x0560)
    case u'ա':    // ARMENIAN SMALL AYB (0x0561)
    case u'բ':    // ARMENIAN SMALL BEN (0x0562)
    case u'գ':    // ARMENIAN SMALL GIM (0x0563)
    case u'դ':    // ARMENIAN SMALL DA (0x0564)
    case u'ե':    // ARMENIAN SMALL ECH (0x0565)
    case u'զ':    // ARMENIAN SMALL ZA (0x0566)
    case u'է':    // ARMENIAN SMALL EH (0x0567)
    case u'ը':    // ARMENIAN SMALL ET (0x0568)
    case u'թ':    // ARMENIAN SMALL TO (0x0569)
    case u'ժ':    // ARMENIAN SMALL ZHE (0x056a)
    case u'ի':    // ARMENIAN SMALL INI (0x056b)
    case u'լ':    // ARMENIAN SMALL LIWN (0x056c)
    case u'խ':    // ARMENIAN SMALL XEH (0x056d)
    case u'ծ':    // ARMENIAN SMALL CA (0x056e)
    case u'կ':    // ARMENIAN SMALL KEN (0x056f)
    case u'հ':    // ARMENIAN SMALL HO (0x0570)
    case u'ձ':    // ARMENIAN SMALL JA (0x0571)
    case u'ղ':    // ARMENIAN SMALL GHAD (0x0572)
    case u'ճ':    // ARMENIAN SMALL CHEH (0x0573)
    case u'մ':    // ARMENIAN SMALL MEN (0x0574)
    case u'յ':    // ARMENIAN SMALL YI (0x0575)
    case u'ն':    // ARMENIAN SMALL NOW (0x0576)
    case u'շ':    // ARMENIAN SMALL SHA (0x0577)
    case u'ո':    // ARMENIAN SMALL VO (0x0578)
    case u'չ':    // ARMENIAN SMALL CHA (0x0579)
    case u'պ':    // ARMENIAN SMALL PEH (0x057a)
    case u'ջ':    // ARMENIAN SMALL JHEH (0x057b)
    case u'ռ':    // ARMENIAN SMALL RA (0x057c)
    case u'ս':    // ARMENIAN SMALL SEH (0x057d)
    case u'վ':    // ARMENIAN SMALL VEW (0x057e)
    case u'տ':    // ARMENIAN SMALL TIWN (0x057f)
    case u'ր':    // ARMENIAN SMALL REH (0x0580)
    case u'ց':    // ARMENIAN SMALL CO (0x0581)
    case u'ւ':    // ARMENIAN SMALL YIWN (0x0582)
    case u'փ':    // ARMENIAN SMALL PIWR (0x0583)
    case u'ք':    // ARMENIAN SMALL KEH (0x0584)
    case u'օ':    // ARMENIAN SMALL OH (0x0585)
    case u'ֆ':    // ARMENIAN SMALL FEH (0x0586)
    case u'և':    // ARMENIAN SMALL LIGATURE ECH YIWN (0x0587)
    case u'ֈ':   // ARMENIAN SMALL YI W/ STROKE (0x0588)
    case u'ა':    // GEORGIAN LETTER AN (0x10d0)
    case u'ბ':    // GEORGIAN LETTER BAN (0x10d1)
    case u'გ':    // GEORGIAN LETTER GAN (0x10d2)
    case u'დ':    // GEORGIAN LETTER DON (0x10d3)
    case u'ე':    // GEORGIAN LETTER EN (0x10d4)
    case u'ვ':    // GEORGIAN LETTER VIN (0x10d5)
    case u'ზ':    // GEORGIAN LETTER ZEN (0x10d6)
    case u'თ':    // GEORGIAN LETTER TAN (0x10d7)
    case u'ი':    // GEORGIAN LETTER IN (0x10d8)
    case u'კ':    // GEORGIAN LETTER KAN (0x10d9)
    case u'ლ':    // GEORGIAN LETTER LAS (0x10da)
    case u'მ':    // GEORGIAN LETTER MAN (0x10db)
    case u'ნ':    // GEORGIAN LETTER NAR (0x10dc)
    case u'ო':    // GEORGIAN LETTER ON (0x10dd)
    case u'პ':    // GEORGIAN LETTER PAR (0x10de)
    case u'ჟ':    // GEORGIAN LETTER ZHAR (0x10df)
    case u'რ':    // GEORGIAN LETTER RAE (0x10e0)
    case u'ს':    // GEORGIAN LETTER SAN (0x10e1)
    case u'ტ':    // GEORGIAN LETTER TAR (0x10e2)
    case u'უ':    // GEORGIAN LETTER UN (0x10e3)
    case u'ფ':    // GEORGIAN LETTER PHAR (0x10e4)
    case u'ქ':    // GEORGIAN LETTER KHAR (0x10e5)
    case u'ღ':    // GEORGIAN LETTER GHAN (0x10e6)
    case u'ყ':    // GEORGIAN LETTER QAR (0x10e7)
    case u'შ':    // GEORGIAN LETTER SHIN (0x10e8)
    case u'ჩ':    // GEORGIAN LETTER CHIN (0x10e9)
    case u'ც':    // GEORGIAN LETTER CAN (0x10ea)
    case u'ძ':    // GEORGIAN LETTER JIL (0x10eb)
    case u'წ':    // GEORGIAN LETTER CIL (0x10ec)
    case u'ჭ':    // GEORGIAN LETTER CHAR (0x10ed)
    case u'ხ':    // GEORGIAN LETTER XAN (0x10ee)
    case u'ჯ':    // GEORGIAN LETTER JHAN (0x10ef)
    case u'ჰ':    // GEORGIAN LETTER HAE (0x10f0)
    case u'ჱ':    // GEORGIAN LETTER HE (0x10f1)
    case u'ჲ':    // GEORGIAN LETTER HIE (0x10f2)
    case u'ჳ':    // GEORGIAN LETTER WE (0x10f3)
    case u'ჴ':    // GEORGIAN LETTER HAR (0x10f4)
    case u'ჵ':    // GEORGIAN LETTER HOE (0x10f5)
    case u'ჶ':    // GEORGIAN LETTER FI (0x10f6)
    case u'ჷ':    // GEORGIAN LETTER YN (0x10f7)
    case u'ჸ':    // GEORGIAN LETTER ELIFI (0x10f8)
    case u'ჹ':    // GEORGIAN LETTER TURNED GAN (0x10f9)
    case u'ჺ':    // GEORGIAN LETTER AIN (0x10fa)
    case u'ჽ':    // GEORGIAN LETTER AEN (0x10fd)
    case u'ჾ':    // GEORGIAN LETTER HARD SIGN (0x10fe)
    case u'ჿ':    // GEORGIAN LETTER LABIAL SIGN (0x10ff)
    case u'ᏸ':  // CHEROKEE SMALL YE (0x13f8)
    case u'ᏹ':  // CHEROKEE SMALL YI (0x13f9)
    case u'ᏺ':  // CHEROKEE SMALL YO (0x13fa)
    case u'ᏻ':  // CHEROKEE SMALL YU (0x13fb)
    case u'ᏼ':  // CHEROKEE SMALL YV (0x13fc)
    case u'ᏽ':  // CHEROKEE SMALL MV (0x13fd)
    case u'ᲀ':  // CYRILLIC SMALL ROUNDED VE (0x1c80)
    case u'ᲁ':  // CYRILLIC SMALL LONG-LEGGED DE (0x1c81)
    case u'ᲂ':  // CYRILLIC SMALL NARROW O (0x1c82)
    case u'ᲃ':  // CYRILLIC SMALL WIDE ES (0x1c83)
    case u'ᲄ':  // CYRILLIC SMALL TALL TE (0x1c84)
    case u'ᲅ':  // CYRILLIC SMALL THREE-LEGGED TE (0x1c85)
    case u'ᲆ':  // CYRILLIC SMALL TALL HARD SIGN (0x1c86)
    case u'ᲇ':  // CYRILLIC SMALL TALL YAT (0x1c87)
    case u'ᲈ':  // CYRILLIC SMALL UNBLENDED UK (0x1c88)
    case u'ᴀ':    // LATIN LETTER SMALL CAPITAL A (0x1d00)
    case u'ᴁ':    // LATIN LETTER SMALL CAPITAL AE (0x1d01)
    case u'ᴂ':    // LATIN SMALL TURNED AE (0x1d02)
    case u'ᴃ':    // LATIN LETTER SMALL CAPITAL BARRED B (0x1d03)
    case u'ᴄ':    // LATIN LETTER SMALL CAPITAL C (0x1d04)
    case u'ᴅ':    // LATIN LETTER SMALL CAPITAL D (0x1d05)
    case u'ᴆ':    // LATIN LETTER SMALL CAPITAL ETH (0x1d06)
    case u'ᴇ':    // LATIN LETTER SMALL CAPITAL E (0x1d07)
    case u'ᴈ':    // LATIN SMALL TURNED OPEN E (0x1d08)
    case u'ᴉ':    // LATIN SMALL TURNED I (0x1d09)
    case u'ᴊ':    // LATIN LETTER SMALL CAPITAL J (0x1d0a)
    case u'ᴋ':    // LATIN LETTER SMALL CAPITAL K (0x1d0b)
    case u'ᴌ':    // LATIN LETTER SMALL CAPITAL L W/ STROKE (0x1d0c)
    case u'ᴍ':    // LATIN LETTER SMALL CAPITAL M (0x1d0d)
    case u'ᴎ':    // LATIN LETTER SMALL CAPITAL REVERSED N (0x1d0e)
    case u'ᴏ':    // LATIN LETTER SMALL CAPITAL O (0x1d0f)
    case u'ᴐ':    // LATIN LETTER SMALL CAPITAL OPEN O (0x1d10)
    case u'ᴑ':    // LATIN SMALL SIDEWAYS O (0x1d11)
    case u'ᴒ':    // LATIN SMALL SIDEWAYS OPEN O (0x1d12)
    case u'ᴓ':    // LATIN SMALL SIDEWAYS O W/ STROKE (0x1d13)
    case u'ᴔ':    // LATIN SMALL TURNED OE (0x1d14)
    case u'ᴕ':    // LATIN LETTER SMALL CAPITAL OU (0x1d15)
    case u'ᴖ':    // LATIN SMALL TOP HALF O (0x1d16)
    case u'ᴗ':    // LATIN SMALL BOTTOM HALF O (0x1d17)
    case u'ᴘ':    // LATIN LETTER SMALL CAPITAL P (0x1d18)
    case u'ᴙ':    // LATIN LETTER SMALL CAPITAL REVERSED R (0x1d19)
    case u'ᴚ':    // LATIN LETTER SMALL CAPITAL TURNED R (0x1d1a)
    case u'ᴛ':    // LATIN LETTER SMALL CAPITAL T (0x1d1b)
    case u'ᴜ':    // LATIN LETTER SMALL CAPITAL U (0x1d1c)
    case u'ᴝ':    // LATIN SMALL SIDEWAYS U (0x1d1d)
    case u'ᴞ':    // LATIN SMALL SIDEWAYS DIAERESIZED U (0x1d1e)
    case u'ᴟ':    // LATIN SMALL SIDEWAYS TURNED M (0x1d1f)
    case u'ᴠ':    // LATIN LETTER SMALL CAPITAL V (0x1d20)
    case u'ᴡ':    // LATIN LETTER SMALL CAPITAL W (0x1d21)
    case u'ᴢ':    // LATIN LETTER SMALL CAPITAL Z (0x1d22)
    case u'ᴣ':    // LATIN LETTER SMALL CAPITAL EZH (0x1d23)
    case u'ᴤ':    // LATIN LETTER VOICED LARYNGEAL SPIRANT (0x1d24)
    case u'ᴥ':    // LATIN LETTER AIN (0x1d25)
    case u'ᴦ':    // GREEK LETTER SMALL CAPITAL GAMMA (0x1d26)
    case u'ᴧ':    // GREEK LETTER SMALL CAPITAL LAMDA (0x1d27)
    case u'ᴨ':    // GREEK LETTER SMALL CAPITAL PI (0x1d28)
    case u'ᴩ':    // GREEK LETTER SMALL CAPITAL RHO (0x1d29)
    case u'ᴪ':    // GREEK LETTER SMALL CAPITAL PSI (0x1d2a)
    case u'ᴫ':    // CYRILLIC LETTER SMALL CAPITAL EL (0x1d2b)
    case u'ᵫ':    // LATIN SMALL UE (0x1d6b)
    case u'ᵬ':    // LATIN SMALL B W/ MIDDLE TILDE (0x1d6c)
    case u'ᵭ':    // LATIN SMALL D W/ MIDDLE TILDE (0x1d6d)
    case u'ᵮ':    // LATIN SMALL F W/ MIDDLE TILDE (0x1d6e)
    case u'ᵯ':    // LATIN SMALL M W/ MIDDLE TILDE (0x1d6f)
    case u'ᵰ':    // LATIN SMALL N W/ MIDDLE TILDE (0x1d70)
    case u'ᵱ':    // LATIN SMALL P W/ MIDDLE TILDE (0x1d71)
    case u'ᵲ':    // LATIN SMALL R W/ MIDDLE TILDE (0x1d72)
    case u'ᵳ':    // LATIN SMALL R W/ FISHHOOK AND MIDDLE TILDE (0x1d73)
    case u'ᵴ':    // LATIN SMALL S W/ MIDDLE TILDE (0x1d74)
    case u'ᵵ':    // LATIN SMALL T W/ MIDDLE TILDE (0x1d75)
    case u'ᵶ':    // LATIN SMALL Z W/ MIDDLE TILDE (0x1d76)
    case u'ᵷ':    // LATIN SMALL TURNED G (0x1d77)
    case u'ᵹ':    // LATIN SMALL INSULAR G (0x1d79)
    case u'ᵺ':    // LATIN SMALL TH W/ STRIKETHROUGH (0x1d7a)
    case u'ᵻ':    // LATIN SMALL CAPITAL LETTER I W/ STROKE (0x1d7b)
    case u'ᵼ':    // LATIN SMALL IOTA W/ STROKE (0x1d7c)
    case u'ᵽ':    // LATIN SMALL P W/ STROKE (0x1d7d)
    case u'ᵾ':    // LATIN SMALL CAPITAL LETTER U W/ STROKE (0x1d7e)
    case u'ᵿ':    // LATIN SMALL UPSILON W/ STROKE (0x1d7f)
    case u'ᶀ':    // LATIN SMALL B W/ PALATAL HOOK (0x1d80)
    case u'ᶁ':    // LATIN SMALL D W/ PALATAL HOOK (0x1d81)
    case u'ᶂ':    // LATIN SMALL F W/ PALATAL HOOK (0x1d82)
    case u'ᶃ':    // LATIN SMALL G W/ PALATAL HOOK (0x1d83)
    case u'ᶄ':    // LATIN SMALL K W/ PALATAL HOOK (0x1d84)
    case u'ᶅ':    // LATIN SMALL L W/ PALATAL HOOK (0x1d85)
    case u'ᶆ':    // LATIN SMALL M W/ PALATAL HOOK (0x1d86)
    case u'ᶇ':    // LATIN SMALL N W/ PALATAL HOOK (0x1d87)
    case u'ᶈ':    // LATIN SMALL P W/ PALATAL HOOK (0x1d88)
    case u'ᶉ':    // LATIN SMALL R W/ PALATAL HOOK (0x1d89)
    case u'ᶊ':    // LATIN SMALL S W/ PALATAL HOOK (0x1d8a)
    case u'ᶋ':    // LATIN SMALL ESH W/ PALATAL HOOK (0x1d8b)
    case u'ᶌ':    // LATIN SMALL V W/ PALATAL HOOK (0x1d8c)
    case u'ᶍ':    // LATIN SMALL X W/ PALATAL HOOK (0x1d8d)
    case u'ᶎ':    // LATIN SMALL Z W/ PALATAL HOOK (0x1d8e)
    case u'ᶏ':    // LATIN SMALL A W/ RETROFLEX HOOK (0x1d8f)
    case u'ᶐ':    // LATIN SMALL ALPHA W/ RETROFLEX HOOK (0x1d90)
    case u'ᶑ':    // LATIN SMALL D W/ HOOK AND TAIL (0x1d91)
    case u'ᶒ':    // LATIN SMALL E W/ RETROFLEX HOOK (0x1d92)
    case u'ᶓ':    // LATIN SMALL OPEN E W/ RETROFLEX HOOK (0x1d93)
    case u'ᶔ':    // LATIN SMALL REVERSED OPEN E W/ RETROFLEX HOOK
                  // (0x1d94)
    case u'ᶕ':    // LATIN SMALL SCHWA W/ RETROFLEX HOOK (0x1d95)
    case u'ᶖ':    // LATIN SMALL I W/ RETROFLEX HOOK (0x1d96)
    case u'ᶗ':    // LATIN SMALL OPEN O W/ RETROFLEX HOOK (0x1d97)
    case u'ᶘ':    // LATIN SMALL ESH W/ RETROFLEX HOOK (0x1d98)
    case u'ᶙ':    // LATIN SMALL U W/ RETROFLEX HOOK (0x1d99)
    case u'ᶚ':    // LATIN SMALL EZH W/ RETROFLEX HOOK (0x1d9a)
    case u'ḁ':    // LATIN SMALL A W/ RING BELOW (0x1e01)
    case u'ḃ':    // LATIN SMALL B W/ DOT ABOVE (0x1e03)
    case u'ḅ':    // LATIN SMALL B W/ DOT BELOW (0x1e05)
    case u'ḇ':    // LATIN SMALL B W/ LINE BELOW (0x1e07)
    case u'ḉ':    // LATIN SMALL C W/ CEDILLA AND ACUTE (0x1e09)
    case u'ḋ':    // LATIN SMALL D W/ DOT ABOVE (0x1e0b)
    case u'ḍ':    // LATIN SMALL D W/ DOT BELOW (0x1e0d)
    case u'ḏ':    // LATIN SMALL D W/ LINE BELOW (0x1e0f)
    case u'ḑ':    // LATIN SMALL D W/ CEDILLA (0x1e11)
    case u'ḓ':    // LATIN SMALL D W/ CIRCUMFLEX BELOW (0x1e13)
    case u'ḕ':    // LATIN SMALL E W/ MACRON AND GRAVE (0x1e15)
    case u'ḗ':    // LATIN SMALL E W/ MACRON AND ACUTE (0x1e17)
    case u'ḙ':    // LATIN SMALL E W/ CIRCUMFLEX BELOW (0x1e19)
    case u'ḛ':    // LATIN SMALL E W/ TILDE BELOW (0x1e1b)
    case u'ḝ':    // LATIN SMALL E W/ CEDILLA AND BREVE (0x1e1d)
    case u'ḟ':    // LATIN SMALL F W/ DOT ABOVE (0x1e1f)
    case u'ḡ':    // LATIN SMALL G W/ MACRON (0x1e21)
    case u'ḣ':    // LATIN SMALL H W/ DOT ABOVE (0x1e23)
    case u'ḥ':    // LATIN SMALL H W/ DOT BELOW (0x1e25)
    case u'ḧ':    // LATIN SMALL H W/ DIAERESIS (0x1e27)
    case u'ḩ':    // LATIN SMALL H W/ CEDILLA (0x1e29)
    case u'ḫ':    // LATIN SMALL H W/ BREVE BELOW (0x1e2b)
    case u'ḭ':    // LATIN SMALL I W/ TILDE BELOW (0x1e2d)
    case u'ḯ':    // LATIN SMALL I W/ DIAERESIS AND ACUTE (0x1e2f)
    case u'ḱ':    // LATIN SMALL K W/ ACUTE (0x1e31)
    case u'ḳ':    // LATIN SMALL K W/ DOT BELOW (0x1e33)
    case u'ḵ':    // LATIN SMALL K W/ LINE BELOW (0x1e35)
    case u'ḷ':    // LATIN SMALL L W/ DOT BELOW (0x1e37)
    case u'ḹ':    // LATIN SMALL L W/ DOT BELOW AND MACRON (0x1e39)
    case u'ḻ':    // LATIN SMALL L W/ LINE BELOW (0x1e3b)
    case u'ḽ':    // LATIN SMALL L W/ CIRCUMFLEX BELOW (0x1e3d)
    case u'ḿ':    // LATIN SMALL M W/ ACUTE (0x1e3f)
    case u'ṁ':    // LATIN SMALL M W/ DOT ABOVE (0x1e41)
    case u'ṃ':    // LATIN SMALL M W/ DOT BELOW (0x1e43)
    case u'ṅ':    // LATIN SMALL N W/ DOT ABOVE (0x1e45)
    case u'ṇ':    // LATIN SMALL N W/ DOT BELOW (0x1e47)
    case u'ṉ':    // LATIN SMALL N W/ LINE BELOW (0x1e49)
    case u'ṋ':    // LATIN SMALL N W/ CIRCUMFLEX BELOW (0x1e4b)
    case u'ṍ':    // LATIN SMALL O W/ TILDE AND ACUTE (0x1e4d)
    case u'ṏ':    // LATIN SMALL O W/ TILDE AND DIAERESIS (0x1e4f)
    case u'ṑ':    // LATIN SMALL O W/ MACRON AND GRAVE (0x1e51)
    case u'ṓ':    // LATIN SMALL O W/ MACRON AND ACUTE (0x1e53)
    case u'ṕ':    // LATIN SMALL P W/ ACUTE (0x1e55)
    case u'ṗ':    // LATIN SMALL P W/ DOT ABOVE (0x1e57)
    case u'ṙ':    // LATIN SMALL R W/ DOT ABOVE (0x1e59)
    case u'ṛ':    // LATIN SMALL R W/ DOT BELOW (0x1e5b)
    case u'ṝ':    // LATIN SMALL R W/ DOT BELOW AND MACRON (0x1e5d)
    case u'ṟ':    // LATIN SMALL R W/ LINE BELOW (0x1e5f)
    case u'ṡ':    // LATIN SMALL S W/ DOT ABOVE (0x1e61)
    case u'ṣ':    // LATIN SMALL S W/ DOT BELOW (0x1e63)
    case u'ṥ':    // LATIN SMALL S W/ ACUTE AND DOT ABOVE (0x1e65)
    case u'ṧ':    // LATIN SMALL S W/ CARON AND DOT ABOVE (0x1e67)
    case u'ṩ':    // LATIN SMALL S W/ DOT BELOW AND DOT ABOVE (0x1e69)
    case u'ṫ':    // LATIN SMALL T W/ DOT ABOVE (0x1e6b)
    case u'ṭ':    // LATIN SMALL T W/ DOT BELOW (0x1e6d)
    case u'ṯ':    // LATIN SMALL T W/ LINE BELOW (0x1e6f)
    case u'ṱ':    // LATIN SMALL T W/ CIRCUMFLEX BELOW (0x1e71)
    case u'ṳ':    // LATIN SMALL U W/ DIAERESIS BELOW (0x1e73)
    case u'ṵ':    // LATIN SMALL U W/ TILDE BELOW (0x1e75)
    case u'ṷ':    // LATIN SMALL U W/ CIRCUMFLEX BELOW (0x1e77)
    case u'ṹ':    // LATIN SMALL U W/ TILDE AND ACUTE (0x1e79)
    case u'ṻ':    // LATIN SMALL U W/ MACRON AND DIAERESIS (0x1e7b)
    case u'ṽ':    // LATIN SMALL V W/ TILDE (0x1e7d)
    case u'ṿ':    // LATIN SMALL V W/ DOT BELOW (0x1e7f)
    case u'ẁ':    // LATIN SMALL W W/ GRAVE (0x1e81)
    case u'ẃ':    // LATIN SMALL W W/ ACUTE (0x1e83)
    case u'ẅ':    // LATIN SMALL W W/ DIAERESIS (0x1e85)
    case u'ẇ':    // LATIN SMALL W W/ DOT ABOVE (0x1e87)
    case u'ẉ':    // LATIN SMALL W W/ DOT BELOW (0x1e89)
    case u'ẋ':    // LATIN SMALL X W/ DOT ABOVE (0x1e8b)
    case u'ẍ':    // LATIN SMALL X W/ DIAERESIS (0x1e8d)
    case u'ẏ':    // LATIN SMALL Y W/ DOT ABOVE (0x1e8f)
    case u'ẑ':    // LATIN SMALL Z W/ CIRCUMFLEX (0x1e91)
    case u'ẓ':    // LATIN SMALL Z W/ DOT BELOW (0x1e93)
    case u'ẕ':    // LATIN SMALL Z W/ LINE BELOW (0x1e95)
    case u'ẖ':    // LATIN SMALL H W/ LINE BELOW (0x1e96)
    case u'ẗ':    // LATIN SMALL T W/ DIAERESIS (0x1e97)
    case u'ẘ':    // LATIN SMALL W W/ RING ABOVE (0x1e98)
    case u'ẙ':    // LATIN SMALL Y W/ RING ABOVE (0x1e99)
    case u'ẚ':    // LATIN SMALL A W/ RIGHT HALF RING (0x1e9a)
    case u'ẛ':    // LATIN SMALL LONG S W/ DOT ABOVE (0x1e9b)
    case u'ẜ':    // LATIN SMALL LONG S W/ DIAGONAL STROKE (0x1e9c)
    case u'ẝ':    // LATIN SMALL LONG S W/ HIGH STROKE (0x1e9d)
    case u'ẟ':    // LATIN SMALL DELTA (0x1e9f)
    case u'ạ':    // LATIN SMALL A W/ DOT BELOW (0x1ea1)
    case u'ả':    // LATIN SMALL A W/ HOOK ABOVE (0x1ea3)
    case u'ấ':    // LATIN SMALL A W/ CIRCUMFLEX AND ACUTE (0x1ea5)
    case u'ầ':    // LATIN SMALL A W/ CIRCUMFLEX AND GRAVE (0x1ea7)
    case u'ẩ':    // LATIN SMALL A W/ CIRCUMFLEX AND HOOK ABOVE (0x1ea9)
    case u'ẫ':    // LATIN SMALL A W/ CIRCUMFLEX AND TILDE (0x1eab)
    case u'ậ':    // LATIN SMALL A W/ CIRCUMFLEX AND DOT BELOW (0x1ead)
    case u'ắ':    // LATIN SMALL A W/ BREVE AND ACUTE (0x1eaf)
    case u'ằ':    // LATIN SMALL A W/ BREVE AND GRAVE (0x1eb1)
    case u'ẳ':    // LATIN SMALL A W/ BREVE AND HOOK ABOVE (0x1eb3)
    case u'ẵ':    // LATIN SMALL A W/ BREVE AND TILDE (0x1eb5)
    case u'ặ':    // LATIN SMALL A W/ BREVE AND DOT BELOW (0x1eb7)
    case u'ẹ':    // LATIN SMALL E W/ DOT BELOW (0x1eb9)
    case u'ẻ':    // LATIN SMALL E W/ HOOK ABOVE (0x1ebb)
    case u'ẽ':    // LATIN SMALL E W/ TILDE (0x1ebd)
    case u'ế':    // LATIN SMALL E W/ CIRCUMFLEX AND ACUTE (0x1ebf)
    case u'ề':    // LATIN SMALL E W/ CIRCUMFLEX AND GRAVE (0x1ec1)
    case u'ể':    // LATIN SMALL E W/ CIRCUMFLEX AND HOOK ABOVE (0x1ec3)
    case u'ễ':    // LATIN SMALL E W/ CIRCUMFLEX AND TILDE (0x1ec5)
    case u'ệ':    // LATIN SMALL E W/ CIRCUMFLEX AND DOT BELOW (0x1ec7)
    case u'ỉ':    // LATIN SMALL I W/ HOOK ABOVE (0x1ec9)
    case u'ị':    // LATIN SMALL I W/ DOT BELOW (0x1ecb)
    case u'ọ':    // LATIN SMALL O W/ DOT BELOW (0x1ecd)
    case u'ỏ':    // LATIN SMALL O W/ HOOK ABOVE (0x1ecf)
    case u'ố':    // LATIN SMALL O W/ CIRCUMFLEX AND ACUTE (0x1ed1)
    case u'ồ':    // LATIN SMALL O W/ CIRCUMFLEX AND GRAVE (0x1ed3)
    case u'ổ':    // LATIN SMALL O W/ CIRCUMFLEX AND HOOK ABOVE (0x1ed5)
    case u'ỗ':    // LATIN SMALL O W/ CIRCUMFLEX AND TILDE (0x1ed7)
    case u'ộ':    // LATIN SMALL O W/ CIRCUMFLEX AND DOT BELOW (0x1ed9)
    case u'ớ':    // LATIN SMALL O W/ HORN AND ACUTE (0x1edb)
    case u'ờ':    // LATIN SMALL O W/ HORN AND GRAVE (0x1edd)
    case u'ở':    // LATIN SMALL O W/ HORN AND HOOK ABOVE (0x1edf)
    case u'ỡ':    // LATIN SMALL O W/ HORN AND TILDE (0x1ee1)
    case u'ợ':    // LATIN SMALL O W/ HORN AND DOT BELOW (0x1ee3)
    case u'ụ':    // LATIN SMALL U W/ DOT BELOW (0x1ee5)
    case u'ủ':    // LATIN SMALL U W/ HOOK ABOVE (0x1ee7)
    case u'ứ':    // LATIN SMALL U W/ HORN AND ACUTE (0x1ee9)
    case u'ừ':    // LATIN SMALL U W/ HORN AND GRAVE (0x1eeb)
    case u'ử':    // LATIN SMALL U W/ HORN AND HOOK ABOVE (0x1eed)
    case u'ữ':    // LATIN SMALL U W/ HORN AND TILDE (0x1eef)
    case u'ự':    // LATIN SMALL U W/ HORN AND DOT BELOW (0x1ef1)
    case u'ỳ':    // LATIN SMALL Y W/ GRAVE (0x1ef3)
    case u'ỵ':    // LATIN SMALL Y W/ DOT BELOW (0x1ef5)
    case u'ỷ':    // LATIN SMALL Y W/ HOOK ABOVE (0x1ef7)
    case u'ỹ':    // LATIN SMALL Y W/ TILDE (0x1ef9)
    case u'ỻ':    // LATIN SMALL MIDDLE-WELSH LL (0x1efb)
    case u'ỽ':    // LATIN SMALL MIDDLE-WELSH V (0x1efd)
    case u'ỿ':    // LATIN SMALL Y W/ LOOP (0x1eff)
    case u'ἀ':    // GREEK SMALL ALPHA W/ PSILI (0x1f00)
    case u'ἁ':    // GREEK SMALL ALPHA W/ DASIA (0x1f01)
    case u'ἂ':    // GREEK SMALL ALPHA W/ PSILI AND VARIA (0x1f02)
    case u'ἃ':    // GREEK SMALL ALPHA W/ DASIA AND VARIA (0x1f03)
    case u'ἄ':    // GREEK SMALL ALPHA W/ PSILI AND OXIA (0x1f04)
    case u'ἅ':    // GREEK SMALL ALPHA W/ DASIA AND OXIA (0x1f05)
    case u'ἆ':    // GREEK SMALL ALPHA W/ PSILI AND PERISPOMENI (0x1f06)
    case u'ἇ':    // GREEK SMALL ALPHA W/ DASIA AND PERISPOMENI (0x1f07)
    case u'ἐ':    // GREEK SMALL EPSILON W/ PSILI (0x1f10)
    case u'ἑ':    // GREEK SMALL EPSILON W/ DASIA (0x1f11)
    case u'ἒ':    // GREEK SMALL EPSILON W/ PSILI AND VARIA (0x1f12)
    case u'ἓ':    // GREEK SMALL EPSILON W/ DASIA AND VARIA (0x1f13)
    case u'ἔ':    // GREEK SMALL EPSILON W/ PSILI AND OXIA (0x1f14)
    case u'ἕ':    // GREEK SMALL EPSILON W/ DASIA AND OXIA (0x1f15)
    case u'ἠ':    // GREEK SMALL ETA W/ PSILI (0x1f20)
    case u'ἡ':    // GREEK SMALL ETA W/ DASIA (0x1f21)
    case u'ἢ':    // GREEK SMALL ETA W/ PSILI AND VARIA (0x1f22)
    case u'ἣ':    // GREEK SMALL ETA W/ DASIA AND VARIA (0x1f23)
    case u'ἤ':    // GREEK SMALL ETA W/ PSILI AND OXIA (0x1f24)
    case u'ἥ':    // GREEK SMALL ETA W/ DASIA AND OXIA (0x1f25)
    case u'ἦ':    // GREEK SMALL ETA W/ PSILI AND PERISPOMENI (0x1f26)
    case u'ἧ':    // GREEK SMALL ETA W/ DASIA AND PERISPOMENI (0x1f27)
    case u'ἰ':    // GREEK SMALL IOTA W/ PSILI (0x1f30)
    case u'ἱ':    // GREEK SMALL IOTA W/ DASIA (0x1f31)
    case u'ἲ':    // GREEK SMALL IOTA W/ PSILI AND VARIA (0x1f32)
    case u'ἳ':    // GREEK SMALL IOTA W/ DASIA AND VARIA (0x1f33)
    case u'ἴ':    // GREEK SMALL IOTA W/ PSILI AND OXIA (0x1f34)
    case u'ἵ':    // GREEK SMALL IOTA W/ DASIA AND OXIA (0x1f35)
    case u'ἶ':    // GREEK SMALL IOTA W/ PSILI AND PERISPOMENI (0x1f36)
    case u'ἷ':    // GREEK SMALL IOTA W/ DASIA AND PERISPOMENI (0x1f37)
    case u'ὀ':    // GREEK SMALL OMICRON W/ PSILI (0x1f40)
    case u'ὁ':    // GREEK SMALL OMICRON W/ DASIA (0x1f41)
    case u'ὂ':    // GREEK SMALL OMICRON W/ PSILI AND VARIA (0x1f42)
    case u'ὃ':    // GREEK SMALL OMICRON W/ DASIA AND VARIA (0x1f43)
    case u'ὄ':    // GREEK SMALL OMICRON W/ PSILI AND OXIA (0x1f44)
    case u'ὅ':    // GREEK SMALL OMICRON W/ DASIA AND OXIA (0x1f45)
    case u'ὐ':    // GREEK SMALL UPSILON W/ PSILI (0x1f50)
    case u'ὑ':    // GREEK SMALL UPSILON W/ DASIA (0x1f51)
    case u'ὒ':    // GREEK SMALL UPSILON W/ PSILI AND VARIA (0x1f52)
    case u'ὓ':    // GREEK SMALL UPSILON W/ DASIA AND VARIA (0x1f53)
    case u'ὔ':    // GREEK SMALL UPSILON W/ PSILI AND OXIA (0x1f54)
    case u'ὕ':    // GREEK SMALL UPSILON W/ DASIA AND OXIA (0x1f55)
    case u'ὖ':    // GREEK SMALL UPSILON W/ PSILI AND PERISPOMENI (0x1f56)
    case u'ὗ':    // GREEK SMALL UPSILON W/ DASIA AND PERISPOMENI (0x1f57)
    case u'ὠ':    // GREEK SMALL OMEGA W/ PSILI (0x1f60)
    case u'ὡ':    // GREEK SMALL OMEGA W/ DASIA (0x1f61)
    case u'ὢ':    // GREEK SMALL OMEGA W/ PSILI AND VARIA (0x1f62)
    case u'ὣ':    // GREEK SMALL OMEGA W/ DASIA AND VARIA (0x1f63)
    case u'ὤ':    // GREEK SMALL OMEGA W/ PSILI AND OXIA (0x1f64)
    case u'ὥ':    // GREEK SMALL OMEGA W/ DASIA AND OXIA (0x1f65)
    case u'ὦ':    // GREEK SMALL OMEGA W/ PSILI AND PERISPOMENI (0x1f66)
    case u'ὧ':    // GREEK SMALL OMEGA W/ DASIA AND PERISPOMENI (0x1f67)
    case u'ὰ':    // GREEK SMALL ALPHA W/ VARIA (0x1f70)
    case u'ά':    // GREEK SMALL ALPHA W/ OXIA (0x1f71)
    case u'ὲ':    // GREEK SMALL EPSILON W/ VARIA (0x1f72)
    case u'έ':    // GREEK SMALL EPSILON W/ OXIA (0x1f73)
    case u'ὴ':    // GREEK SMALL ETA W/ VARIA (0x1f74)
    case u'ή':    // GREEK SMALL ETA W/ OXIA (0x1f75)
    case u'ὶ':    // GREEK SMALL IOTA W/ VARIA (0x1f76)
    case u'ί':    // GREEK SMALL IOTA W/ OXIA (0x1f77)
    case u'ὸ':    // GREEK SMALL OMICRON W/ VARIA (0x1f78)
    case u'ό':    // GREEK SMALL OMICRON W/ OXIA (0x1f79)
    case u'ὺ':    // GREEK SMALL UPSILON W/ VARIA (0x1f7a)
    case u'ύ':    // GREEK SMALL UPSILON W/ OXIA (0x1f7b)
    case u'ὼ':    // GREEK SMALL OMEGA W/ VARIA (0x1f7c)
    case u'ώ':    // GREEK SMALL OMEGA W/ OXIA (0x1f7d)
    case u'ᾀ':    // GREEK SMALL ALPHA W/ PSILI YPOGEGRAMMENI (0x1f80)
    case u'ᾁ':    // GREEK SMALL ALPHA W/ DASIA YPOGEGRAMMENI (0x1f81)
    case u'ᾂ':    // GREEK SMALL ALPHA W/ PSILI VARIA YPOGEGRAMMENI (0x1f82)
    case u'ᾃ':    // GREEK SMALL ALPHA W/ DASIA VARIA YPOGEGRAMMENI (0x1f83)
    case u'ᾄ':    // GREEK SMALL ALPHA W/ PSILI OXIA YPOGEGRAMMENI (0x1f84)
    case u'ᾅ':    // GREEK SMALL ALPHA W/ DASIA OXIA YPOGEGRAMMENI (0x1f85)
    case u'ᾆ':  // GREEK SMALL ALPHA W/ PSILI PERISPOMENI YPOGEGRAMMENI (0x1f86)
    case u'ᾇ':  // GREEK SMALL ALPHA W/ DASIA PERISPOMENI YPOGEGRAMMENI (0x1f87)
    case u'ᾐ':  // GREEK SMALL ETA W/ PSILI YPOGEGRAMMENI (0x1f90)
    case u'ᾑ':  // GREEK SMALL ETA W/ DASIA YPOGEGRAMMENI (0x1f91)
    case u'ᾒ':  // GREEK SMALL ETA W/ PSILI VARIA YPOGEGRAMMENI 0x1f92)
    case u'ᾓ':  // GREEK SMALL ETA W/ DASIA VARIA YPOGEGRAMMENI 0x1f93)
    case u'ᾔ':  // GREEK SMALL ETA W/ PSILI OXIA YPOGEGRAMMENI 0x1f94)
    case u'ᾕ':  // GREEK SMALL ETA W/ DASIA OXIA YPOGEGRAMMENI 0x1f95)
    case u'ᾖ':  // GREEK SMALL ETA W/ PSILI PERISPOMENI YPOGEGRAMMENI (0x1f96)
    case u'ᾗ':  // GREEK SMALL ETA W/ DASIA PERISPOMENI YPOGEGRAMMENI (0x1f97)
    case u'ᾠ':  // GREEK SMALL OMEGA W/ PSILI YPOGEGRAMMENI (0x1fa0)
    case u'ᾡ':  // GREEK SMALL OMEGA W/ DASIA YPOGEGRAMMENI (0x1fa1)
    case u'ᾢ':  // GREEK SMALL OMEGA W/ PSILI VARIA YPOGEGRAMMENI (0x1fa2)
    case u'ᾣ':  // GREEK SMALL OMEGA W/ DASIA VARIA YPOGEGRAMMENI (0x1fa3)
    case u'ᾤ':  // GREEK SMALL OMEGA W/ PSILI OXIA YPOGEGRAMMENI (0x1fa4)
    case u'ᾥ':  // GREEK SMALL OMEGA W/ DASIA OXIA YPOGEGRAMMENI (0x1fa5)
    case u'ᾦ':  // GREEK SMALL OMEGA W/ PSILI PERISPOMENI YPOGEGRAMMENI (0x1fa6)
    case u'ᾧ':  // GREEK SMALL OMEGA W/ DASIA PERISPOMENI YPOGEGRAMMENI (0x1fa7)
    case u'ᾰ':  // GREEK SMALL ALPHA W/ VRACHY (0x1fb0)
    case u'ᾱ':  // GREEK SMALL ALPHA W/ MACRON (0x1fb1)
    case u'ᾲ':  // GREEK SMALL ALPHA W/ VARIA YPOGEGRAMMENI (0x1fb2)
    case u'ᾳ':  // GREEK SMALL ALPHA W/ YPOGEGRAMMENI (0x1fb3)
    case u'ᾴ':  // GREEK SMALL ALPHA W/ OXIA AND YPOGEGRAMMENI (0x1fb4)
    case u'ᾶ':  // GREEK SMALL ALPHA W/ PERISPOMENI (0x1fb6)
    case u'ᾷ':  // GREEK SMALL ALPHA W/ PERISPOMENI AND YPOGEGRAMMENI (0x1fb7)
    case u'ι':  // GREEK PROSGEGRAMMENI (0x1fbe)
    case u'ῂ':  // GREEK SMALL ETA W/ VARIA AND YPOGEGRAMMENI (0x1fc2)
    case u'ῃ':  // GREEK SMALL ETA W/ YPOGEGRAMMENI (0x1fc3)
    case u'ῄ':  // GREEK SMALL ETA W/ OXIA AND YPOGEGRAMMENI (0x1fc4)
    case u'ῆ':  // GREEK SMALL ETA W/ PERISPOMENI (0x1fc6)
    case u'ῇ':  // GREEK SMALL ETA W/ PERISPOMENI AND YPOGEGRAMMENI (0x1fc7)
    case u'ῐ':  // GREEK SMALL IOTA W/ VRACHY (0x1fd0)
    case u'ῑ':  // GREEK SMALL IOTA W/ MACRON (0x1fd1)
    case u'ῒ':  // GREEK SMALL IOTA W/ DIALYTIKA AND VARIA (0x1fd2)
    case u'ΐ':  // GREEK SMALL IOTA W/ DIALYTIKA AND OXIA (0x1fd3)
    case u'ῖ':  // GREEK SMALL IOTA W/ PERISPOMENI (0x1fd6)
    case u'ῗ':  // GREEK SMALL IOTA W/ DIALYTIKA AND PERISPOMENI (0x1fd7)
    case u'ῠ':  // GREEK SMALL UPSILON W/ VRACHY (0x1fe0)
    case u'ῡ':  // GREEK SMALL UPSILON W/ MACRON (0x1fe1)
    case u'ῢ':  // GREEK SMALL UPSILON W/ DIALYTIKA AND VARIA (0x1fe2)
    case u'ΰ':  // GREEK SMALL UPSILON W/ DIALYTIKA AND OXIA (0x1fe3)
    case u'ῤ':  // GREEK SMALL RHO W/ PSILI (0x1fe4)
    case u'ῥ':  // GREEK SMALL RHO W/ DASIA (0x1fe5)
    case u'ῦ':  // GREEK SMALL UPSILON W/ PERISPOMENI (0x1fe6)
    case u'ῧ':  // GREEK SMALL UPSILON W/ DIALYTIKA AND PERISPOMENI (0x1fe7)
    case u'ῲ':  // GREEK SMALL OMEGA W/ VARIA AND YPOGEGRAMMENI (0x1ff2)
    case u'ῳ':  // GREEK SMALL OMEGA W/ YPOGEGRAMMENI (0x1ff3)
    case u'ῴ':  // GREEK SMALL OMEGA W/ OXIA AND YPOGEGRAMMENI (0x1ff4)
    case u'ῶ':  // GREEK SMALL OMEGA W/ PERISPOMENI (0x1ff6)
    case u'ῷ':  // GREEK SMALL OMEGA W/ PERISPOMENI AND YPOGEGRAMMENI (0x1ff7)
    case u'ℊ':  // SCRIPT SMALL G (0x210a)
    case u'ℎ':  // PLANCK CONSTANT (0x210e)
    case u'ℏ':  // PLANCK CONSTANT OVER TWO PI (0x210f)
    case u'ℓ':  // SCRIPT SMALL L (0x2113)
    case u'ℯ':  // SCRIPT SMALL E (0x212f)
    case u'ℴ':  // SCRIPT SMALL O (0x2134)
    case u'ℹ':  // INFORMATION SOURCE (0x2139)
    case u'ℼ':  // DOUBLE-STRUCK SMALL PI (0x213c)
    case u'ℽ':  // DOUBLE-STRUCK SMALL GAMMA (0x213d)
    case u'ⅆ':  // DOUBLE-STRUCK ITALIC SMALL D (0x2146)
    case u'ⅇ':  // DOUBLE-STRUCK ITALIC SMALL E (0x2147)
    case u'ⅈ':  // DOUBLE-STRUCK ITALIC SMALL I (0x2148)
    case u'ⅉ':  // DOUBLE-STRUCK ITALIC SMALL J (0x2149)
    case u'ⅎ':  // TURNED SMALL F (0x214e)
    case u'ↄ':  // LATIN SMALL REVERSED C (0x2184)
    case u'ⰰ':  // GLAGOLITIC SMALL AZU (0x2c30)
    case u'ⰱ':  // GLAGOLITIC SMALL BUKY (0x2c31)
    case u'ⰲ':  // GLAGOLITIC SMALL VEDE (0x2c32)
    case u'ⰳ':  // GLAGOLITIC SMALL GLAGOLI (0x2c33)
    case u'ⰴ':  // GLAGOLITIC SMALL DOBRO (0x2c34)
    case u'ⰵ':  // GLAGOLITIC SMALL YESTU (0x2c35)
    case u'ⰶ':  // GLAGOLITIC SMALL ZHIVETE (0x2c36)
    case u'ⰷ':  // GLAGOLITIC SMALL DZELO (0x2c37)
    case u'ⰸ':  // GLAGOLITIC SMALL ZEMLJA (0x2c38)
    case u'ⰹ':  // GLAGOLITIC SMALL IZHE (0x2c39)
    case u'ⰺ':  // GLAGOLITIC SMALL INITIAL IZHE (0x2c3a)
    case u'ⰻ':  // GLAGOLITIC SMALL I (0x2c3b)
    case u'ⰼ':  // GLAGOLITIC SMALL DJERVI (0x2c3c)
    case u'ⰽ':  // GLAGOLITIC SMALL KAKO (0x2c3d)
    case u'ⰾ':  // GLAGOLITIC SMALL LJUDIJE (0x2c3e)
    case u'ⰿ':  // GLAGOLITIC SMALL MYSLITE (0x2c3f)
    case u'ⱀ':  // GLAGOLITIC SMALL NASHI (0x2c40)
    case u'ⱁ':  // GLAGOLITIC SMALL ONU (0x2c41)
    case u'ⱂ':  // GLAGOLITIC SMALL POKOJI (0x2c42)
    case u'ⱃ':  // GLAGOLITIC SMALL RITSI (0x2c43)
    case u'ⱄ':  // GLAGOLITIC SMALL SLOVO (0x2c44)
    case u'ⱅ':  // GLAGOLITIC SMALL TVRIDO (0x2c45)
    case u'ⱆ':  // GLAGOLITIC SMALL UKU (0x2c46)
    case u'ⱇ':  // GLAGOLITIC SMALL FRITU (0x2c47)
    case u'ⱈ':  // GLAGOLITIC SMALL HERU (0x2c48)
    case u'ⱉ':  // GLAGOLITIC SMALL OTU (0x2c49)
    case u'ⱊ':  // GLAGOLITIC SMALL PE (0x2c4a)
    case u'ⱋ':  // GLAGOLITIC SMALL SHTA (0x2c4b)
    case u'ⱌ':  // GLAGOLITIC SMALL TSI (0x2c4c)
    case u'ⱍ':  // GLAGOLITIC SMALL CHRIVI (0x2c4d)
    case u'ⱎ':  // GLAGOLITIC SMALL SHA (0x2c4e)
    case u'ⱏ':  // GLAGOLITIC SMALL YERU (0x2c4f)
    case u'ⱐ':  // GLAGOLITIC SMALL YERI (0x2c50)
    case u'ⱑ':  // GLAGOLITIC SMALL YATI (0x2c51)
    case u'ⱒ':  // GLAGOLITIC SMALL SPIDERY HA (0x2c52)
    case u'ⱓ':  // GLAGOLITIC SMALL YU (0x2c53)
    case u'ⱔ':  // GLAGOLITIC SMALL SMALL YUS (0x2c54)
    case u'ⱕ':  // GLAGOLITIC SMALL SMALL YUS W/ TAIL (0x2c55)
    case u'ⱖ':  // GLAGOLITIC SMALL YO (0x2c56)
    case u'ⱗ':  // GLAGOLITIC SMALL IOTATED SMALL YUS (0x2c57)
    case u'ⱘ':  // GLAGOLITIC SMALL BIG YUS (0x2c58)
    case u'ⱙ':  // GLAGOLITIC SMALL IOTATED BIG YUS (0x2c59)
    case u'ⱚ':  // GLAGOLITIC SMALL FITA (0x2c5a)
    case u'ⱛ':  // GLAGOLITIC SMALL IZHITSA (0x2c5b)
    case u'ⱜ':  // GLAGOLITIC SMALL SHTAPIC (0x2c5c)
    case u'ⱝ':  // GLAGOLITIC SMALL TROKUTASTI A (0x2c5d)
    case u'ⱞ':  // GLAGOLITIC SMALL LATINATE MYSLITE (0x2c5e)
    case u'ⱡ':  // LATIN SMALL L W/ DOUBLE BAR (0x2c61)
    case u'ⱥ':  // LATIN SMALL A W/ STROKE (0x2c65)
    case u'ⱦ':  // LATIN SMALL T W/ DIAGONAL STROKE (0x2c66)
    case u'ⱨ':  // LATIN SMALL H W/ DESCENDER (0x2c68)
    case u'ⱪ':  // LATIN SMALL K W/ DESCENDER (0x2c6a)
    case u'ⱬ':  // LATIN SMALL Z W/ DESCENDER (0x2c6c)
    case u'ⱱ':  // LATIN SMALL V W/ RIGHT HOOK (0x2c71)
    case u'ⱳ':  // LATIN SMALL W W/ HOOK (0x2c73)
    case u'ⱴ':  // LATIN SMALL V W/ CURL (0x2c74)
    case u'ⱶ':  // LATIN SMALL HALF H (0x2c76)
    case u'ⱷ':  // LATIN SMALL TAILLESS PHI (0x2c77)
    case u'ⱸ':  // LATIN SMALL E W/ NOTCH (0x2c78)
    case u'ⱹ':  // LATIN SMALL TURNED R W/ TAIL (0x2c79)
    case u'ⱺ':  // LATIN SMALL O W/ LOW RING INSIDE (0x2c7a)
    case u'ⱻ':  // LATIN LETTER SMALL CAPITAL TURNED E (0x2c7b)
    case u'ⲁ':  // COPTIC SMALL ALFA (0x2c81)
    case u'ⲃ':  // COPTIC SMALL VIDA (0x2c83)
    case u'ⲅ':  // COPTIC SMALL GAMMA (0x2c85)
    case u'ⲇ':  // COPTIC SMALL DALDA (0x2c87)
    case u'ⲉ':  // COPTIC SMALL EIE (0x2c89)
    case u'ⲋ':  // COPTIC SMALL SOU (0x2c8b)
    case u'ⲍ':  // COPTIC SMALL ZATA (0x2c8d)
    case u'ⲏ':  // COPTIC SMALL HATE (0x2c8f)
    case u'ⲑ':  // COPTIC SMALL THETHE (0x2c91)
    case u'ⲓ':  // COPTIC SMALL IAUDA (0x2c93)
    case u'ⲕ':  // COPTIC SMALL KAPA (0x2c95)
    case u'ⲗ':  // COPTIC SMALL LAULA (0x2c97)
    case u'ⲙ':  // COPTIC SMALL MI (0x2c99)
    case u'ⲛ':  // COPTIC SMALL NI (0x2c9b)
    case u'ⲝ':  // COPTIC SMALL KSI (0x2c9d)
    case u'ⲟ':  // COPTIC SMALL O (0x2c9f)
    case u'ⲡ':  // COPTIC SMALL PI (0x2ca1)
    case u'ⲣ':  // COPTIC SMALL RO (0x2ca3)
    case u'ⲥ':  // COPTIC SMALL SIMA (0x2ca5)
    case u'ⲧ':  // COPTIC SMALL TAU (0x2ca7)
    case u'ⲩ':  // COPTIC SMALL UA (0x2ca9)
    case u'ⲫ':  // COPTIC SMALL FI (0x2cab)
    case u'ⲭ':  // COPTIC SMALL KHI (0x2cad)
    case u'ⲯ':  // COPTIC SMALL PSI (0x2caf)
    case u'ⲱ':  // COPTIC SMALL OOU (0x2cb1)
    case u'ⲳ':  // COPTIC SMALL DIALECT-P ALEF (0x2cb3)
    case u'ⲵ':  // COPTIC SMALL OLD COPTIC AIN (0x2cb5)
    case u'ⲷ':  // COPTIC SMALL CRYPTOGRAMMIC EIE (0x2cb7)
    case u'ⲹ':  // COPTIC SMALL DIALECT-P KAPA (0x2cb9)
    case u'ⲻ':  // COPTIC SMALL DIALECT-P NI (0x2cbb)
    case u'ⲽ':  // COPTIC SMALL CRYPTOGRAMMIC NI (0x2cbd)
    case u'ⲿ':  // COPTIC SMALL OLD COPTIC OOU (0x2cbf)
    case u'ⳁ':  // COPTIC SMALL SAMPI (0x2cc1)
    case u'ⳃ':  // COPTIC SMALL CROSSED SHEI (0x2cc3)
    case u'ⳅ':  // COPTIC SMALL OLD COPTIC SHEI (0x2cc5)
    case u'ⳇ':  // COPTIC SMALL OLD COPTIC ESH (0x2cc7)
    case u'ⳉ':  // COPTIC SMALL AKHMIMIC KHEI (0x2cc9)
    case u'ⳋ':  // COPTIC SMALL DIALECT-P HORI (0x2ccb)
    case u'ⳍ':  // COPTIC SMALL OLD COPTIC HORI (0x2ccd)
    case u'ⳏ':  // COPTIC SMALL OLD COPTIC HA (0x2ccf)
    case u'ⳑ':  // COPTIC SMALL L-SHAPED HA (0x2cd1)
    case u'ⳓ':  // COPTIC SMALL OLD COPTIC HEI (0x2cd3)
    case u'ⳕ':  // COPTIC SMALL OLD COPTIC HAT (0x2cd5)
    case u'ⳗ':  // COPTIC SMALL OLD COPTIC GANGIA (0x2cd7)
    case u'ⳙ':  // COPTIC SMALL OLD COPTIC DJA (0x2cd9)
    case u'ⳛ':  // COPTIC SMALL OLD COPTIC SHIMA (0x2cdb)
    case u'ⳝ':  // COPTIC SMALL OLD NUBIAN SHIMA (0x2cdd)
    case u'ⳟ':  // COPTIC SMALL OLD NUBIAN NGI (0x2cdf)
    case u'ⳡ':  // COPTIC SMALL OLD NUBIAN NYI (0x2ce1)
    case u'ⳣ':  // COPTIC SMALL OLD NUBIAN WAU (0x2ce3)
    case u'ⳤ':  // COPTIC SYMBOL KAI (0x2ce4)
    case u'ⳬ':  // COPTIC SMALL CRYPTOGRAMMIC SHEI (0x2cec)
    case u'ⳮ':  // COPTIC SMALL CRYPTOGRAMMIC GANGIA (0x2cee)
    case u'ⳳ':  // COPTIC SMALL BOHAIRIC KHEI (0x2cf3)
    case u'ⴀ':  // GEORGIAN SMALL AN (0x2d00)
    case u'ⴁ':  // GEORGIAN SMALL BAN (0x2d01)
    case u'ⴂ':  // GEORGIAN SMALL GAN (0x2d02)
    case u'ⴃ':  // GEORGIAN SMALL DON (0x2d03)
    case u'ⴄ':  // GEORGIAN SMALL EN (0x2d04)
    case u'ⴅ':  // GEORGIAN SMALL VIN (0x2d05)
    case u'ⴆ':  // GEORGIAN SMALL ZEN (0x2d06)
    case u'ⴇ':  // GEORGIAN SMALL TAN (0x2d07)
    case u'ⴈ':  // GEORGIAN SMALL IN (0x2d08)
    case u'ⴉ':  // GEORGIAN SMALL KAN (0x2d09)
    case u'ⴊ':  // GEORGIAN SMALL LAS (0x2d0a)
    case u'ⴋ':  // GEORGIAN SMALL MAN (0x2d0b)
    case u'ⴌ':  // GEORGIAN SMALL NAR (0x2d0c)
    case u'ⴍ':  // GEORGIAN SMALL ON (0x2d0d)
    case u'ⴎ':  // GEORGIAN SMALL PAR (0x2d0e)
    case u'ⴏ':  // GEORGIAN SMALL ZHAR (0x2d0f)
    case u'ⴐ':  // GEORGIAN SMALL RAE (0x2d10)
    case u'ⴑ':  // GEORGIAN SMALL SAN (0x2d11)
    case u'ⴒ':  // GEORGIAN SMALL TAR (0x2d12)
    case u'ⴓ':  // GEORGIAN SMALL UN (0x2d13)
    case u'ⴔ':  // GEORGIAN SMALL PHAR (0x2d14)
    case u'ⴕ':  // GEORGIAN SMALL KHAR (0x2d15)
    case u'ⴖ':  // GEORGIAN SMALL GHAN (0x2d16)
    case u'ⴗ':  // GEORGIAN SMALL QAR (0x2d17)
    case u'ⴘ':  // GEORGIAN SMALL SHIN (0x2d18)
    case u'ⴙ':  // GEORGIAN SMALL CHIN (0x2d19)
    case u'ⴚ':  // GEORGIAN SMALL CAN (0x2d1a)
    case u'ⴛ':  // GEORGIAN SMALL JIL (0x2d1b)
    case u'ⴜ':  // GEORGIAN SMALL CIL (0x2d1c)
    case u'ⴝ':  // GEORGIAN SMALL CHAR (0x2d1d)
    case u'ⴞ':  // GEORGIAN SMALL XAN (0x2d1e)
    case u'ⴟ':  // GEORGIAN SMALL JHAN (0x2d1f)
    case u'ⴠ':  // GEORGIAN SMALL HAE (0x2d20)
    case u'ⴡ':  // GEORGIAN SMALL HE (0x2d21)
    case u'ⴢ':  // GEORGIAN SMALL HIE (0x2d22)
    case u'ⴣ':  // GEORGIAN SMALL WE (0x2d23)
    case u'ⴤ':  // GEORGIAN SMALL HAR (0x2d24)
    case u'ⴥ':  // GEORGIAN SMALL HOE (0x2d25)
    case u'ⴧ':  // GEORGIAN SMALL YN (0x2d27)
    case u'ⴭ':  // GEORGIAN SMALL AEN (0x2d2d)
    case u'ꙁ':  // CYRILLIC SMALL ZEMLYA (0xa641)
    case u'ꙃ':  // CYRILLIC SMALL DZELO (0xa643)
    case u'ꙅ':  // CYRILLIC SMALL REVERSED DZE (0xa645)
    case u'ꙇ':  // CYRILLIC SMALL IOTA (0xa647)
    case u'ꙉ':  // CYRILLIC SMALL DJERV (0xa649)
    case u'ꙋ':  // CYRILLIC SMALL MONOGRAPH UK (0xa64b)
    case u'ꙍ':  // CYRILLIC SMALL BROAD OMEGA (0xa64d)
    case u'ꙏ':  // CYRILLIC SMALL NEUTRAL YER (0xa64f)
    case u'ꙑ':  // CYRILLIC SMALL YERU W/ BACK YER (0xa651)
    case u'ꙓ':  // CYRILLIC SMALL IOTIFIED YAT (0xa653)
    case u'ꙕ':  // CYRILLIC SMALL REVERSED YU (0xa655)
    case u'ꙗ':  // CYRILLIC SMALL IOTIFIED A (0xa657)
    case u'ꙙ':  // CYRILLIC SMALL CLOSED LITTLE YUS (0xa659)
    case u'ꙛ':  // CYRILLIC SMALL BLENDED YUS (0xa65b)
    case u'ꙝ':  // CYRILLIC SMALL IOTIFIED CLOSED LITTLE YUS (0xa65d)
    case u'ꙟ':  // CYRILLIC SMALL YN (0xa65f)
    case u'ꙡ':  // CYRILLIC SMALL REVERSED TSE (0xa661)
    case u'ꙣ':  // CYRILLIC SMALL SOFT DE (0xa663)
    case u'ꙥ':  // CYRILLIC SMALL SOFT EL (0xa665)
    case u'ꙧ':  // CYRILLIC SMALL SOFT EM (0xa667)
    case u'ꙩ':  // CYRILLIC SMALL MONOCULAR O (0xa669)
    case u'ꙫ':  // CYRILLIC SMALL BINOCULAR O (0xa66b)
    case u'ꙭ':  // CYRILLIC SMALL DOUBLE MONOCULAR O (0xa66d)
    case 0xa681:   // CYRILLIC SMALL DWE (0xa681)
    case 0xa683:   // CYRILLIC SMALL DZWE (0xa683)
    case 0xa685:   // CYRILLIC SMALL ZHWE (0xa685)
    case 0xa687:   // CYRILLIC SMALL CCHE (0xa687)
    case 0xa689:   // CYRILLIC SMALL DZZE (0xa689)
    case 0xa68b:   // CYRILLIC SMALL TE W/ MIDDLE HOOK (0xa68b)
    case 0xa68d:   // CYRILLIC SMALL TWE (0xa68d)
    case 0xa68f:   // CYRILLIC SMALL TSWE (0xa68f)
    case 0xa691:   // CYRILLIC SMALL TSSE (0xa691)
    case 0xa693:   // CYRILLIC SMALL TCHE (0xa693)
    case 0xa695:   // CYRILLIC SMALL HWE (0xa695)
    case 0xa697:   // CYRILLIC SMALL SHWE (0xa697)
    case 0xa699:   // CYRILLIC SMALL DOUBLE O (0xa699)
    case 0xa69b:   // CYRILLIC SMALL CROSSED O (0xa69b)
    case u'ꜣ':     // LATIN SMALL EGYPTOLOGICAL ALEF (0xa723)
    case u'ꜥ':     // LATIN SMALL EGYPTOLOGICAL AIN (0xa725)
    case u'ꜧ':     // LATIN SMALL HENG (0xa727)
    case u'ꜩ':     // LATIN SMALL TZ (0xa729)
    case u'ꜫ':     // LATIN SMALL TRESILLO (0xa72b)
    case u'ꜭ':     // LATIN SMALL CUATRILLO (0xa72d)
    case u'ꜯ':     // LATIN SMALL CUATRILLO W/ COMMA (0xa72f)
    case u'ꜰ':     // LATIN LETTER SMALL CAPITAL F (0xa730)
    case u'ꜱ':     // LATIN LETTER SMALL CAPITAL S (0xa731)
    case u'ꜳ':     // LATIN SMALL AA (0xa733)
    case u'ꜵ':     // LATIN SMALL AO (0xa735)
    case u'ꜷ':     // LATIN SMALL AU (0xa737)
    case u'ꜹ':     // LATIN SMALL AV (0xa739)
    case u'ꜻ':     // LATIN SMALL AV W/ HORIZONTAL BAR (0xa73b)
    case u'ꜽ':     // LATIN SMALL AY (0xa73d)
    case u'ꜿ':     // LATIN SMALL REVERSED C W/ DOT (0xa73f)
    case u'ꝁ':     // LATIN SMALL K W/ STROKE (0xa741)
    case u'ꝃ':     // LATIN SMALL K W/ DIAGONAL STROKE (0xa743)
    case u'ꝅ':     // LATIN SMALL K W/ STROKE AND DIAGONAL STROKE (0xa745)
    case u'ꝇ':     // LATIN SMALL BROKEN L (0xa747)
    case u'ꝉ':     // LATIN SMALL L W/ HIGH STROKE (0xa749)
    case u'ꝋ':     // LATIN SMALL O W/ LONG STROKE OVERLAY (0xa74b)
    case u'ꝍ':     // LATIN SMALL O W/ LOOP (0xa74d)
    case u'ꝏ':     // LATIN SMALL OO (0xa74f)
    case u'ꝑ':     // LATIN SMALL P W/ STROKE THROUGH DESCENDER (0xa751)
    case u'ꝓ':     // LATIN SMALL P W/ FLOURISH (0xa753)
    case u'ꝕ':     // LATIN SMALL P W/ SQUIRREL TAIL (0xa755)
    case u'ꝗ':     // LATIN SMALL Q W/ STROKE THROUGH DESCENDER (0xa757)
    case u'ꝙ':     // LATIN SMALL Q W/ DIAGONAL STROKE (0xa759)
    case u'ꝛ':     // LATIN SMALL R ROTUNDA (0xa75b)
    case u'ꝝ':     // LATIN SMALL RUM ROTUNDA (0xa75d)
    case u'ꝟ':     // LATIN SMALL V W/ DIAGONAL STROKE (0xa75f)
    case u'ꝡ':     // LATIN SMALL VY (0xa761)
    case u'ꝣ':     // LATIN SMALL VISIGOTHIC Z (0xa763)
    case u'ꝥ':     // LATIN SMALL THORN W/ STROKE (0xa765)
    case u'ꝧ':     // LATIN SMALL THORN W/ STROKE THROUGH DESCENDER
                   // (0xa767)
    case u'ꝩ':     // LATIN SMALL VEND (0xa769)
    case u'ꝫ':     // LATIN SMALL ET (0xa76b)
    case u'ꝭ':     // LATIN SMALL IS (0xa76d)
    case u'ꝯ':     // LATIN SMALL CON (0xa76f)
    case u'ꝱ':     // LATIN SMALL DUM (0xa771)
    case u'ꝲ':     // LATIN SMALL LUM (0xa772)
    case u'ꝳ':     // LATIN SMALL MUM (0xa773)
    case u'ꝴ':     // LATIN SMALL NUM (0xa774)
    case u'ꝵ':     // LATIN SMALL RUM (0xa775)
    case u'ꝶ':     // LATIN LETTER SMALL CAPITAL RUM (0xa776)
    case u'ꝷ':     // LATIN SMALL TUM (0xa777)
    case u'ꝸ':     // LATIN SMALL UM (0xa778)
    case u'ꝺ':     // LATIN SMALL INSULAR D (0xa77a)
    case u'ꝼ':     // LATIN SMALL INSULAR F (0xa77c)
    case u'ꝿ':     // LATIN SMALL TURNED INSULAR G (0xa77f)
    case u'ꞁ':     // LATIN SMALL TURNED L (0xa781)
    case u'ꞃ':     // LATIN SMALL INSULAR R (0xa783)
    case u'ꞅ':     // LATIN SMALL INSULAR S (0xa785)
    case u'ꞇ':     // LATIN SMALL INSULAR T (0xa787)
    case u'ꞌ':     // LATIN SMALL SALTILLO (0xa78c)
    case u'ꞎ':     // LATIN SMALL L W/ RETROFLEX HOOK AND BELT (0xa78e)
    case u'ꞑ':     // LATIN SMALL N W/ DESCENDER (0xa791)
    case u'ꞓ':     // LATIN SMALL C W/ BAR (0xa793)
    case u'ꞔ':   // LATIN SMALL C W/ PALATAL HOOK (0xa794)
    case u'ꞕ':   // LATIN SMALL H W/ PALATAL HOOK (0xa795)
    case u'ꞗ':   // LATIN SMALL B W/ FLOURISH (0xa797)
    case u'ꞙ':   // LATIN SMALL F W/ STROKE (0xa799)
    case u'ꞛ':   // LATIN SMALL VOLAPUK AE (0xa79b)
    case u'ꞝ':   // LATIN SMALL VOLAPUK OE (0xa79d)
    case u'ꞟ':   // LATIN SMALL VOLAPUK UE (0xa79f)
    case u'ꞡ':     // LATIN SMALL G W/ OBLIQUE STROKE (0xa7a1)
    case u'ꞣ':     // LATIN SMALL K W/ OBLIQUE STROKE (0xa7a3)
    case u'ꞥ':     // LATIN SMALL N W/ OBLIQUE STROKE (0xa7a5)
    case u'ꞧ':     // LATIN SMALL R W/ OBLIQUE STROKE (0xa7a7)
    case u'ꞩ':     // LATIN SMALL S W/ OBLIQUE STROKE (0xa7a9)
    case u'ꞯ':   // LATIN LETTER SMALL CAPITAL Q (0xa7af)
    case u'ꞵ':   // LATIN SMALL BETA (0xa7b5)
    case u'ꞷ':   // LATIN SMALL OMEGA (0xa7b7)
    case u'ꞹ':   // LATIN SMALL U W/ STROKE (0xa7b9)
    case u'ꞻ':   // LATIN SMALL GLOTTAL A (0xa7bb)
    case u'ꞽ':   // LATIN SMALL GLOTTAL I (0xa7bd)
    case u'ꞿ':   // LATIN SMALL GLOTTAL U (0xa7bf)
    case u'ꟃ':   // LATIN SMALL ANGLICANA W (0xa7c3)
    case u'ꟺ':     // LATIN LETTER SMALL CAPITAL TURNED M (0xa7fa)
    case u'ꬰ':   // LATIN SMALL BARRED ALPHA (0xab30)
    case u'ꬱ':   // LATIN SMALL A REVERSED-SCHWA (0xab31)
    case u'ꬲ':   // LATIN SMALL BLACKLETTER E (0xab32)
    case u'ꬳ':   // LATIN SMALL BARRED E (0xab33)
    case u'ꬴ':   // LATIN SMALL E W/ FLOURISH (0xab34)
    case u'ꬵ':   // LATIN SMALL LENIS F (0xab35)
    case u'ꬶ':   // LATIN SMALL SCRIPT G W/ CROSSED-TAIL (0xab36)
    case u'ꬷ':   // LATIN SMALL L W/ INVERTED LAZY S (0xab37)
    case u'ꬸ':   // LATIN SMALL L W/ DOUBLE MIDDLE TILDE (0xab38)
    case u'ꬹ':   // LATIN SMALL L W/ MIDDLE RING (0xab39)
    case u'ꬺ':   // LATIN SMALL M W/ CROSSED-TAIL (0xab3a)
    case u'ꬻ':   // LATIN SMALL N W/ CROSSED-TAIL (0xab3b)
    case u'ꬼ':   // LATIN SMALL ENG W/ CROSSED-TAIL (0xab3c)
    case u'ꬽ':   // LATIN SMALL BLACKLETTER O (0xab3d)
    case u'ꬾ':   // LATIN SMALL BLACKLETTER O W/ STROKE (0xab3e)
    case u'ꬿ':   // LATIN SMALL OPEN O W/ STROKE (0xab3f)
    case u'ꭀ':   // LATIN SMALL INVERTED OE (0xab40)
    case u'ꭁ':   // LATIN SMALL TURNED OE W/ STROKE (0xab41)
    case u'ꭂ':   // LATIN SMALL TURNED OE W/ HORIZONTAL STROKE (0xab42)
    case u'ꭃ':   // LATIN SMALL TURNED O OPEN-O (0xab43)
    case u'ꭄ':   // LATIN SMALL TURNED O OPEN-O W/ STROKE (0xab44)
    case u'ꭅ':   // LATIN SMALL STIRRUP R (0xab45)
    case u'ꭆ':   // LATIN LETTER SMALL CAPITAL R W/ RIGHT LEG (0xab46)
    case u'ꭇ':   // LATIN SMALL R WITHOUT HANDLE (0xab47)
    case u'ꭈ':   // LATIN SMALL DOUBLE R (0xab48)
    case u'ꭉ':   // LATIN SMALL R W/ CROSSED-TAIL (0xab49)
    case u'ꭊ':   // LATIN SMALL DOUBLE R W/ CROSSED-TAIL (0xab4a)
    case u'ꭋ':   // LATIN SMALL SCRIPT R (0xab4b)
    case u'ꭌ':   // LATIN SMALL SCRIPT R W/ RING (0xab4c)
    case u'ꭍ':   // LATIN SMALL BASELINE ESH (0xab4d)
    case u'ꭎ':   // LATIN SMALL U W/ SHORT RIGHT LEG (0xab4e)
    case u'ꭏ':   // LATIN SMALL U BAR W/ SHORT RIGHT LEG (0xab4f)
    case u'ꭐ':   // LATIN SMALL UI (0xab50)
    case u'ꭑ':   // LATIN SMALL TURNED UI (0xab51)
    case u'ꭒ':   // LATIN SMALL U W/ LEFT HOOK (0xab52)
    case u'ꭓ':   // LATIN SMALL CHI (0xab53)
    case u'ꭔ':   // LATIN SMALL CHI W/ LOW RIGHT RING (0xab54)
    case u'ꭕ':   // LATIN SMALL CHI W/ LOW LEFT SERIF (0xab55)
    case u'ꭖ':   // LATIN SMALL X W/ LOW RIGHT RING (0xab56)
    case u'ꭗ':   // LATIN SMALL X W/ LONG LEFT LEG (0xab57)
    case u'ꭘ':   // LATIN SMALL X W/ LONG LEFT LEG AND LOW RIGHT RING (0xab58)
    case u'ꭙ':   // LATIN SMALL X W/ LONG LEFT LEG W/ SERIF (0xab59)
    case u'ꭚ':   // LATIN SMALL Y W/ SHORT RIGHT LEG (0xab5a)
    case u'ꭠ':   // LATIN SMALL SAKHA YAT (0xab60)
    case u'ꭡ':   // LATIN SMALL IOTIFIED E (0xab61)
    case u'ꭢ':   // LATIN SMALL OPEN OE (0xab62)
    case u'ꭣ':   // LATIN SMALL UO (0xab63)
    case u'ꭤ':   // LATIN SMALL INVERTED ALPHA (0xab64)
    case u'ꭥ':   // GREEK LETTER SMALL CAPITAL OMEGA (0xab65)
    case u'ꭦ':   // LATIN SMALL DZ DIGRAPH W/ RETROFLEX HOOK (0xab66)
    case u'ꭧ':   // LATIN SMALL TS DIGRAPH W/ RETROFLEX HOOK (0xab67)
    case u'ꭰ':   // CHEROKEE SMALL A (0xab70)
    case u'ꭱ':   // CHEROKEE SMALL E (0xab71)
    case u'ꭲ':   // CHEROKEE SMALL I (0xab72)
    case u'ꭳ':   // CHEROKEE SMALL O (0xab73)
    case u'ꭴ':   // CHEROKEE SMALL U (0xab74)
    case u'ꭵ':   // CHEROKEE SMALL V (0xab75)
    case u'ꭶ':   // CHEROKEE SMALL GA (0xab76)
    case u'ꭷ':   // CHEROKEE SMALL KA (0xab77)
    case u'ꭸ':   // CHEROKEE SMALL GE (0xab78)
    case u'ꭹ':   // CHEROKEE SMALL GI (0xab79)
    case u'ꭺ':   // CHEROKEE SMALL GO (0xab7a)
    case u'ꭻ':   // CHEROKEE SMALL GU (0xab7b)
    case u'ꭼ':   // CHEROKEE SMALL GV (0xab7c)
    case u'ꭽ':   // CHEROKEE SMALL HA (0xab7d)
    case u'ꭾ':   // CHEROKEE SMALL HE (0xab7e)
    case u'ꭿ':   // CHEROKEE SMALL HI (0xab7f)
    case u'ꮀ':   // CHEROKEE SMALL HO (0xab80)
    case u'ꮁ':   // CHEROKEE SMALL HU (0xab81)
    case u'ꮂ':   // CHEROKEE SMALL HV (0xab82)
    case u'ꮃ':   // CHEROKEE SMALL LA (0xab83)
    case u'ꮄ':   // CHEROKEE SMALL LE (0xab84)
    case u'ꮅ':   // CHEROKEE SMALL LI (0xab85)
    case u'ꮆ':   // CHEROKEE SMALL LO (0xab86)
    case u'ꮇ':   // CHEROKEE SMALL LU (0xab87)
    case u'ꮈ':   // CHEROKEE SMALL LV (0xab88)
    case u'ꮉ':   // CHEROKEE SMALL MA (0xab89)
    case u'ꮊ':   // CHEROKEE SMALL ME (0xab8a)
    case u'ꮋ':   // CHEROKEE SMALL MI (0xab8b)
    case u'ꮌ':   // CHEROKEE SMALL MO (0xab8c)
    case u'ꮍ':   // CHEROKEE SMALL MU (0xab8d)
    case u'ꮎ':   // CHEROKEE SMALL NA (0xab8e)
    case u'ꮏ':   // CHEROKEE SMALL HNA (0xab8f)
    case u'ꮐ':   // CHEROKEE SMALL NAH (0xab90)
    case u'ꮑ':   // CHEROKEE SMALL NE (0xab91)
    case u'ꮒ':   // CHEROKEE SMALL NI (0xab92)
    case u'ꮓ':   // CHEROKEE SMALL NO (0xab93)
    case u'ꮔ':   // CHEROKEE SMALL NU (0xab94)
    case u'ꮕ':   // CHEROKEE SMALL NV (0xab95)
    case u'ꮖ':   // CHEROKEE SMALL QUA (0xab96)
    case u'ꮗ':   // CHEROKEE SMALL QUE (0xab97)
    case u'ꮘ':   // CHEROKEE SMALL QUI (0xab98)
    case u'ꮙ':   // CHEROKEE SMALL QUO (0xab99)
    case u'ꮚ':   // CHEROKEE SMALL QUU (0xab9a)
    case u'ꮛ':   // CHEROKEE SMALL QUV (0xab9b)
    case u'ꮜ':   // CHEROKEE SMALL SA (0xab9c)
    case u'ꮝ':   // CHEROKEE SMALL S (0xab9d)
    case u'ꮞ':   // CHEROKEE SMALL SE (0xab9e)
    case u'ꮟ':   // CHEROKEE SMALL SI (0xab9f)
    case u'ꮠ':   // CHEROKEE SMALL SO (0xaba0)
    case u'ꮡ':   // CHEROKEE SMALL SU (0xaba1)
    case u'ꮢ':   // CHEROKEE SMALL SV (0xaba2)
    case u'ꮣ':   // CHEROKEE SMALL DA (0xaba3)
    case u'ꮤ':   // CHEROKEE SMALL TA (0xaba4)
    case u'ꮥ':   // CHEROKEE SMALL DE (0xaba5)
    case u'ꮦ':   // CHEROKEE SMALL TE (0xaba6)
    case u'ꮧ':   // CHEROKEE SMALL DI (0xaba7)
    case u'ꮨ':   // CHEROKEE SMALL TI (0xaba8)
    case u'ꮩ':   // CHEROKEE SMALL DO (0xaba9)
    case u'ꮪ':   // CHEROKEE SMALL DU (0xabaa)
    case u'ꮫ':   // CHEROKEE SMALL DV (0xabab)
    case u'ꮬ':   // CHEROKEE SMALL DLA (0xabac)
    case u'ꮭ':   // CHEROKEE SMALL TLA (0xabad)
    case u'ꮮ':   // CHEROKEE SMALL TLE (0xabae)
    case u'ꮯ':   // CHEROKEE SMALL TLI (0xabaf)
    case u'ꮰ':   // CHEROKEE SMALL TLO (0xabb0)
    case u'ꮱ':   // CHEROKEE SMALL TLU (0xabb1)
    case u'ꮲ':   // CHEROKEE SMALL TLV (0xabb2)
    case u'ꮳ':   // CHEROKEE SMALL TSA (0xabb3)
    case u'ꮴ':   // CHEROKEE SMALL TSE (0xabb4)
    case u'ꮵ':   // CHEROKEE SMALL TSI (0xabb5)
    case u'ꮶ':   // CHEROKEE SMALL TSO (0xabb6)
    case u'ꮷ':   // CHEROKEE SMALL TSU (0xabb7)
    case u'ꮸ':   // CHEROKEE SMALL TSV (0xabb8)
    case u'ꮹ':   // CHEROKEE SMALL WA (0xabb9)
    case u'ꮺ':   // CHEROKEE SMALL WE (0xabba)
    case u'ꮻ':   // CHEROKEE SMALL WI (0xabbb)
    case u'ꮼ':   // CHEROKEE SMALL WO (0xabbc)
    case u'ꮽ':   // CHEROKEE SMALL WU (0xabbd)
    case u'ꮾ':   // CHEROKEE SMALL WV (0xabbe)
    case u'ꮿ':   // CHEROKEE SMALL YA (0xabbf)
    case u'ﬀ':     // LATIN SMALL LIGATURE FF (0xfb00)
    case u'ﬁ':     // LATIN SMALL LIGATURE FI (0xfb01)
    case u'ﬂ':     // LATIN SMALL LIGATURE FL (0xfb02)
    case u'ﬃ':     // LATIN SMALL LIGATURE FFI (0xfb03)
    case u'ﬄ':     // LATIN SMALL LIGATURE FFL (0xfb04)
    case u'ﬅ':     // LATIN SMALL LIGATURE LONG S T (0xfb05)
    case u'ﬆ':     // LATIN SMALL LIGATURE ST (0xfb06)
    case u'ﬓ':     // ARMENIAN SMALL LIGATURE MEN NOW (0xfb13)
    case u'ﬔ':     // ARMENIAN SMALL LIGATURE MEN ECH (0xfb14)
    case u'ﬕ':     // ARMENIAN SMALL LIGATURE MEN INI (0xfb15)
    case u'ﬖ':     // ARMENIAN SMALL LIGATURE VEW NOW (0xfb16)
    case u'ﬗ':     // ARMENIAN SMALL LIGATURE MEN XEH (0xfb17)
    case u'ａ':    // FULLWIDTH LATIN SMALL A (0xff41)
    case u'ｂ':    // FULLWIDTH LATIN SMALL B (0xff42)
    case u'ｃ':    // FULLWIDTH LATIN SMALL C (0xff43)
    case u'ｄ':    // FULLWIDTH LATIN SMALL D (0xff44)
    case u'ｅ':    // FULLWIDTH LATIN SMALL E (0xff45)
    case u'ｆ':    // FULLWIDTH LATIN SMALL F (0xff46)
    case u'ｇ':    // FULLWIDTH LATIN SMALL G (0xff47)
    case u'ｈ':    // FULLWIDTH LATIN SMALL H (0xff48)
    case u'ｉ':    // FULLWIDTH LATIN SMALL I (0xff49)
    case u'ｊ':    // FULLWIDTH LATIN SMALL J (0xff4a)
    case u'ｋ':    // FULLWIDTH LATIN SMALL K (0xff4b)
    case u'ｌ':    // FULLWIDTH LATIN SMALL L (0xff4c)
    case u'ｍ':    // FULLWIDTH LATIN SMALL M (0xff4d)
    case u'ｎ':    // FULLWIDTH LATIN SMALL N (0xff4e)
    case u'ｏ':    // FULLWIDTH LATIN SMALL O (0xff4f)
    case u'ｐ':    // FULLWIDTH LATIN SMALL P (0xff50)
    case u'ｑ':    // FULLWIDTH LATIN SMALL Q (0xff51)
    case u'ｒ':    // FULLWIDTH LATIN SMALL R (0xff52)
    case u'ｓ':    // FULLWIDTH LATIN SMALL S (0xff53)
    case u'ｔ':    // FULLWIDTH LATIN SMALL T (0xff54)
    case u'ｕ':    // FULLWIDTH LATIN SMALL U (0xff55)
    case u'ｖ':    // FULLWIDTH LATIN SMALL V (0xff56)
    case u'ｗ':    // FULLWIDTH LATIN SMALL W (0xff57)
    case u'ｘ':    // FULLWIDTH LATIN SMALL X (0xff58)
    case u'ｙ':    // FULLWIDTH LATIN SMALL Y (0xff59)
    case u'ｚ':    // FULLWIDTH LATIN SMALL Z (0xff5a)
    case L'𐐨':     // DESERET SMALL LONG I (0x10428)
    case L'𐐩':     // DESERET SMALL LONG E (0x10429)
    case L'𐐪':     // DESERET SMALL LONG A (0x1042a)
    case L'𐐫':     // DESERET SMALL LONG AH (0x1042b)
    case L'𐐬':     // DESERET SMALL LONG O (0x1042c)
    case L'𐐭':     // DESERET SMALL LONG OO (0x1042d)
    case L'𐐮':     // DESERET SMALL SHORT I (0x1042e)
    case L'𐐯':     // DESERET SMALL SHORT E (0x1042f)
    case L'𐐰':     // DESERET SMALL SHORT A (0x10430)
    case L'𐐱':     // DESERET SMALL SHORT AH (0x10431)
    case L'𐐲':     // DESERET SMALL SHORT O (0x10432)
    case L'𐐳':     // DESERET SMALL SHORT OO (0x10433)
    case L'𐐴':     // DESERET SMALL AY (0x10434)
    case L'𐐵':     // DESERET SMALL OW (0x10435)
    case L'𐐶':     // DESERET SMALL WU (0x10436)
    case L'𐐷':     // DESERET SMALL YEE (0x10437)
    case L'𐐸':     // DESERET SMALL H (0x10438)
    case L'𐐹':     // DESERET SMALL PEE (0x10439)
    case L'𐐺':     // DESERET SMALL BEE (0x1043a)
    case L'𐐻':     // DESERET SMALL TEE (0x1043b)
    case L'𐐼':     // DESERET SMALL DEE (0x1043c)
    case L'𐐽':     // DESERET SMALL CHEE (0x1043d)
    case L'𐐾':     // DESERET SMALL JEE (0x1043e)
    case L'𐐿':     // DESERET SMALL KAY (0x1043f)
    case L'𐑀':     // DESERET SMALL GAY (0x10440)
    case L'𐑁':     // DESERET SMALL EF (0x10441)
    case L'𐑂':     // DESERET SMALL VEE (0x10442)
    case L'𐑃':     // DESERET SMALL ETH (0x10443)
    case L'𐑄':     // DESERET SMALL THEE (0x10444)
    case L'𐑅':     // DESERET SMALL ES (0x10445)
    case L'𐑆':     // DESERET SMALL ZEE (0x10446)
    case L'𐑇':     // DESERET SMALL ESH (0x10447)
    case L'𐑈':     // DESERET SMALL ZHEE (0x10448)
    case L'𐑉':     // DESERET SMALL ER (0x10449)
    case L'𐑊':     // DESERET SMALL EL (0x1044a)
    case L'𐑋':     // DESERET SMALL EM (0x1044b)
    case L'𐑌':     // DESERET SMALL EN (0x1044c)
    case L'𐑍':     // DESERET SMALL ENG (0x1044d)
    case L'𐑎':     // DESERET SMALL OI (0x1044e)
    case L'𐑏':     // DESERET SMALL EW (0x1044f)
    case L'𐓘':  // OSAGE SMALL A (0x104d8)
    case L'𐓙':  // OSAGE SMALL AI (0x104d9)
    case L'𐓚':  // OSAGE SMALL AIN (0x104da)
    case L'𐓛':  // OSAGE SMALL AH (0x104db)
    case L'𐓜':  // OSAGE SMALL BRA (0x104dc)
    case L'𐓝':  // OSAGE SMALL CHA (0x104dd)
    case L'𐓞':  // OSAGE SMALL EHCHA (0x104de)
    case L'𐓟':  // OSAGE SMALL E (0x104df)
    case L'𐓠':  // OSAGE SMALL EIN (0x104e0)
    case L'𐓡':  // OSAGE SMALL HA (0x104e1)
    case L'𐓢':  // OSAGE SMALL HYA (0x104e2)
    case L'𐓣':  // OSAGE SMALL I (0x104e3)
    case L'𐓤':  // OSAGE SMALL KA (0x104e4)
    case L'𐓥':  // OSAGE SMALL EHKA (0x104e5)
    case L'𐓦':  // OSAGE SMALL KYA (0x104e6)
    case L'𐓧':  // OSAGE SMALL LA (0x104e7)
    case L'𐓨':  // OSAGE SMALL MA (0x104e8)
    case L'𐓩':  // OSAGE SMALL NA (0x104e9)
    case L'𐓪':  // OSAGE SMALL O (0x104ea)
    case L'𐓫':  // OSAGE SMALL OIN (0x104eb)
    case L'𐓬':  // OSAGE SMALL PA (0x104ec)
    case L'𐓭':  // OSAGE SMALL EHPA (0x104ed)
    case L'𐓮':  // OSAGE SMALL SA (0x104ee)
    case L'𐓯':  // OSAGE SMALL SHA (0x104ef)
    case L'𐓰':  // OSAGE SMALL TA (0x104f0)
    case L'𐓱':  // OSAGE SMALL EHTA (0x104f1)
    case L'𐓲':  // OSAGE SMALL TSA (0x104f2)
    case L'𐓳':  // OSAGE SMALL EHTSA (0x104f3)
    case L'𐓴':  // OSAGE SMALL TSHA (0x104f4)
    case L'𐓵':  // OSAGE SMALL DHA (0x104f5)
    case L'𐓶':  // OSAGE SMALL U (0x104f6)
    case L'𐓷':  // OSAGE SMALL WA (0x104f7)
    case L'𐓸':  // OSAGE SMALL KHA (0x104f8)
    case L'𐓹':  // OSAGE SMALL GHA (0x104f9)
    case L'𐓺':  // OSAGE SMALL ZA (0x104fa)
    case L'𐓻':  // OSAGE SMALL ZHA (0x104fb)
    case L'𐳀':  // OLD HUNGARIAN SMALL A (0x10cc0)
    case L'𐳁':  // OLD HUNGARIAN SMALL AA (0x10cc1)
    case L'𐳂':  // OLD HUNGARIAN SMALL EB (0x10cc2)
    case L'𐳃':  // OLD HUNGARIAN SMALL AMB (0x10cc3)
    case L'𐳄':  // OLD HUNGARIAN SMALL EC (0x10cc4)
    case L'𐳅':  // OLD HUNGARIAN SMALL ENC (0x10cc5)
    case L'𐳆':  // OLD HUNGARIAN SMALL ECS (0x10cc6)
    case L'𐳇':  // OLD HUNGARIAN SMALL ED (0x10cc7)
    case L'𐳈':  // OLD HUNGARIAN SMALL AND (0x10cc8)
    case L'𐳉':  // OLD HUNGARIAN SMALL E (0x10cc9)
    case L'𐳊':  // OLD HUNGARIAN SMALL CLOSE E (0x10cca)
    case L'𐳋':  // OLD HUNGARIAN SMALL EE (0x10ccb)
    case L'𐳌':  // OLD HUNGARIAN SMALL EF (0x10ccc)
    case L'𐳍':  // OLD HUNGARIAN SMALL EG (0x10ccd)
    case L'𐳎':  // OLD HUNGARIAN SMALL EGY (0x10cce)
    case L'𐳏':  // OLD HUNGARIAN SMALL EH (0x10ccf)
    case L'𐳐':  // OLD HUNGARIAN SMALL I (0x10cd0)
    case L'𐳑':  // OLD HUNGARIAN SMALL II (0x10cd1)
    case L'𐳒':  // OLD HUNGARIAN SMALL EJ (0x10cd2)
    case L'𐳓':  // OLD HUNGARIAN SMALL EK (0x10cd3)
    case L'𐳔':  // OLD HUNGARIAN SMALL AK (0x10cd4)
    case L'𐳕':  // OLD HUNGARIAN SMALL UNK (0x10cd5)
    case L'𐳖':  // OLD HUNGARIAN SMALL EL (0x10cd6)
    case L'𐳗':  // OLD HUNGARIAN SMALL ELY (0x10cd7)
    case L'𐳘':  // OLD HUNGARIAN SMALL EM (0x10cd8)
    case L'𐳙':  // OLD HUNGARIAN SMALL EN (0x10cd9)
    case L'𐳚':  // OLD HUNGARIAN SMALL ENY (0x10cda)
    case L'𐳛':  // OLD HUNGARIAN SMALL O (0x10cdb)
    case L'𐳜':  // OLD HUNGARIAN SMALL OO (0x10cdc)
    case L'𐳝':  // OLD HUNGARIAN SMALL NIKOLSBURG OE (0x10cdd)
    case L'𐳞':  // OLD HUNGARIAN SMALL RUDIMENTA OE (0x10cde)
    case L'𐳟':  // OLD HUNGARIAN SMALL OEE (0x10cdf)
    case L'𐳠':  // OLD HUNGARIAN SMALL EP (0x10ce0)
    case L'𐳡':  // OLD HUNGARIAN SMALL EMP (0x10ce1)
    case L'𐳢':  // OLD HUNGARIAN SMALL ER (0x10ce2)
    case L'𐳣':  // OLD HUNGARIAN SMALL SHORT ER (0x10ce3)
    case L'𐳤':  // OLD HUNGARIAN SMALL ES (0x10ce4)
    case L'𐳥':  // OLD HUNGARIAN SMALL ESZ (0x10ce5)
    case L'𐳦':  // OLD HUNGARIAN SMALL ET (0x10ce6)
    case L'𐳧':  // OLD HUNGARIAN SMALL ENT (0x10ce7)
    case L'𐳨':  // OLD HUNGARIAN SMALL ETY (0x10ce8)
    case L'𐳩':  // OLD HUNGARIAN SMALL ECH (0x10ce9)
    case L'𐳪':  // OLD HUNGARIAN SMALL U (0x10cea)
    case L'𐳫':  // OLD HUNGARIAN SMALL UU (0x10ceb)
    case L'𐳬':  // OLD HUNGARIAN SMALL NIKOLSBURG UE (0x10cec)
    case L'𐳭':  // OLD HUNGARIAN SMALL RUDIMENTA UE (0x10ced)
    case L'𐳮':  // OLD HUNGARIAN SMALL EV (0x10cee)
    case L'𐳯':  // OLD HUNGARIAN SMALL EZ (0x10cef)
    case L'𐳰':  // OLD HUNGARIAN SMALL EZS (0x10cf0)
    case L'𐳱':  // OLD HUNGARIAN SMALL ENT-SHAPED SIGN (0x10cf1)
    case L'𐳲':  // OLD HUNGARIAN SMALL US (0x10cf2)
    case L'𑣀':  // WARANG CITI SMALL NGAA (0x118c0)
    case L'𑣁':  // WARANG CITI SMALL A (0x118c1)
    case L'𑣂':  // WARANG CITI SMALL WI (0x118c2)
    case L'𑣃':  // WARANG CITI SMALL YU (0x118c3)
    case L'𑣄':  // WARANG CITI SMALL YA (0x118c4)
    case L'𑣅':  // WARANG CITI SMALL YO (0x118c5)
    case L'𑣆':  // WARANG CITI SMALL II (0x118c6)
    case L'𑣇':  // WARANG CITI SMALL UU (0x118c7)
    case L'𑣈':  // WARANG CITI SMALL E (0x118c8)
    case L'𑣉':  // WARANG CITI SMALL O (0x118c9)
    case L'𑣊':  // WARANG CITI SMALL ANG (0x118ca)
    case L'𑣋':  // WARANG CITI SMALL GA (0x118cb)
    case L'𑣌':  // WARANG CITI SMALL KO (0x118cc)
    case L'𑣍':  // WARANG CITI SMALL ENY (0x118cd)
    case L'𑣎':  // WARANG CITI SMALL YUJ (0x118ce)
    case L'𑣏':  // WARANG CITI SMALL UC (0x118cf)
    case L'𑣐':  // WARANG CITI SMALL ENN (0x118d0)
    case L'𑣑':  // WARANG CITI SMALL ODD (0x118d1)
    case L'𑣒':  // WARANG CITI SMALL TTE (0x118d2)
    case L'𑣓':  // WARANG CITI SMALL NUNG (0x118d3)
    case L'𑣔':  // WARANG CITI SMALL DA (0x118d4)
    case L'𑣕':  // WARANG CITI SMALL AT (0x118d5)
    case L'𑣖':  // WARANG CITI SMALL AM (0x118d6)
    case L'𑣗':  // WARANG CITI SMALL BU (0x118d7)
    case L'𑣘':  // WARANG CITI SMALL PU (0x118d8)
    case L'𑣙':  // WARANG CITI SMALL HIYO (0x118d9)
    case L'𑣚':  // WARANG CITI SMALL HOLO (0x118da)
    case L'𑣛':  // WARANG CITI SMALL HORR (0x118db)
    case L'𑣜':  // WARANG CITI SMALL HAR (0x118dc)
    case L'𑣝':  // WARANG CITI SMALL SSUU (0x118dd)
    case L'𑣞':  // WARANG CITI SMALL SII (0x118de)
    case L'𑣟':  // WARANG CITI SMALL VIYO (0x118df)
    case L'𖹠':  // MEDEFAIDRIN SMALL M (0x16e60)
    case L'𖹡':  // MEDEFAIDRIN SMALL S (0x16e61)
    case L'𖹢':  // MEDEFAIDRIN SMALL V (0x16e62)
    case L'𖹣':  // MEDEFAIDRIN SMALL W (0x16e63)
    case L'𖹤':  // MEDEFAIDRIN SMALL ATIU (0x16e64)
    case L'𖹥':  // MEDEFAIDRIN SMALL Z (0x16e65)
    case L'𖹦':  // MEDEFAIDRIN SMALL KP (0x16e66)
    case L'𖹧':  // MEDEFAIDRIN SMALL P (0x16e67)
    case L'𖹨':  // MEDEFAIDRIN SMALL T (0x16e68)
    case L'𖹩':  // MEDEFAIDRIN SMALL G (0x16e69)
    case L'𖹪':  // MEDEFAIDRIN SMALL F (0x16e6a)
    case L'𖹫':  // MEDEFAIDRIN SMALL I (0x16e6b)
    case L'𖹬':  // MEDEFAIDRIN SMALL K (0x16e6c)
    case L'𖹭':  // MEDEFAIDRIN SMALL A (0x16e6d)
    case L'𖹮':  // MEDEFAIDRIN SMALL J (0x16e6e)
    case L'𖹯':  // MEDEFAIDRIN SMALL E (0x16e6f)
    case L'𖹰':  // MEDEFAIDRIN SMALL B (0x16e70)
    case L'𖹱':  // MEDEFAIDRIN SMALL C (0x16e71)
    case L'𖹲':  // MEDEFAIDRIN SMALL U (0x16e72)
    case L'𖹳':  // MEDEFAIDRIN SMALL YU (0x16e73)
    case L'𖹴':  // MEDEFAIDRIN SMALL L (0x16e74)
    case L'𖹵':  // MEDEFAIDRIN SMALL Q (0x16e75)
    case L'𖹶':  // MEDEFAIDRIN SMALL HP (0x16e76)
    case L'𖹷':  // MEDEFAIDRIN SMALL NY (0x16e77)
    case L'𖹸':  // MEDEFAIDRIN SMALL X (0x16e78)
    case L'𖹹':  // MEDEFAIDRIN SMALL D (0x16e79)
    case L'𖹺':  // MEDEFAIDRIN SMALL OE (0x16e7a)
    case L'𖹻':  // MEDEFAIDRIN SMALL N (0x16e7b)
    case L'𖹼':  // MEDEFAIDRIN SMALL R (0x16e7c)
    case L'𖹽':  // MEDEFAIDRIN SMALL O (0x16e7d)
    case L'𖹾':  // MEDEFAIDRIN SMALL AI (0x16e7e)
    case L'𖹿':  // MEDEFAIDRIN SMALL Y (0x16e7f)
    case L'𝐚':     // MATHEMATICAL BOLD SMALL A (0x1d41a)
    case L'𝐛':     // MATHEMATICAL BOLD SMALL B (0x1d41b)
    case L'𝐜':     // MATHEMATICAL BOLD SMALL C (0x1d41c)
    case L'𝐝':     // MATHEMATICAL BOLD SMALL D (0x1d41d)
    case L'𝐞':     // MATHEMATICAL BOLD SMALL E (0x1d41e)
    case L'𝐟':     // MATHEMATICAL BOLD SMALL F (0x1d41f)
    case L'𝐠':     // MATHEMATICAL BOLD SMALL G (0x1d420)
    case L'𝐡':     // MATHEMATICAL BOLD SMALL H (0x1d421)
    case L'𝐢':     // MATHEMATICAL BOLD SMALL I (0x1d422)
    case L'𝐣':     // MATHEMATICAL BOLD SMALL J (0x1d423)
    case L'𝐤':     // MATHEMATICAL BOLD SMALL K (0x1d424)
    case L'𝐥':     // MATHEMATICAL BOLD SMALL L (0x1d425)
    case L'𝐦':     // MATHEMATICAL BOLD SMALL M (0x1d426)
    case L'𝐧':     // MATHEMATICAL BOLD SMALL N (0x1d427)
    case L'𝐨':     // MATHEMATICAL BOLD SMALL O (0x1d428)
    case L'𝐩':     // MATHEMATICAL BOLD SMALL P (0x1d429)
    case L'𝐪':     // MATHEMATICAL BOLD SMALL Q (0x1d42a)
    case L'𝐫':     // MATHEMATICAL BOLD SMALL R (0x1d42b)
    case L'𝐬':     // MATHEMATICAL BOLD SMALL S (0x1d42c)
    case L'𝐭':     // MATHEMATICAL BOLD SMALL T (0x1d42d)
    case L'𝐮':     // MATHEMATICAL BOLD SMALL U (0x1d42e)
    case L'𝐯':     // MATHEMATICAL BOLD SMALL V (0x1d42f)
    case L'𝐰':     // MATHEMATICAL BOLD SMALL W (0x1d430)
    case L'𝐱':     // MATHEMATICAL BOLD SMALL X (0x1d431)
    case L'𝐲':     // MATHEMATICAL BOLD SMALL Y (0x1d432)
    case L'𝐳':     // MATHEMATICAL BOLD SMALL Z (0x1d433)
    case L'𝑎':     // MATHEMATICAL ITALIC SMALL A (0x1d44e)
    case L'𝑏':     // MATHEMATICAL ITALIC SMALL B (0x1d44f)
    case L'𝑐':     // MATHEMATICAL ITALIC SMALL C (0x1d450)
    case L'𝑑':     // MATHEMATICAL ITALIC SMALL D (0x1d451)
    case L'𝑒':     // MATHEMATICAL ITALIC SMALL E (0x1d452)
    case L'𝑓':     // MATHEMATICAL ITALIC SMALL F (0x1d453)
    case L'𝑔':     // MATHEMATICAL ITALIC SMALL G (0x1d454)
    case L'𝑖':     // MATHEMATICAL ITALIC SMALL I (0x1d456)
    case L'𝑗':     // MATHEMATICAL ITALIC SMALL J (0x1d457)
    case L'𝑘':     // MATHEMATICAL ITALIC SMALL K (0x1d458)
    case L'𝑙':     // MATHEMATICAL ITALIC SMALL L (0x1d459)
    case L'𝑚':     // MATHEMATICAL ITALIC SMALL M (0x1d45a)
    case L'𝑛':     // MATHEMATICAL ITALIC SMALL N (0x1d45b)
    case L'𝑜':     // MATHEMATICAL ITALIC SMALL O (0x1d45c)
    case L'𝑝':     // MATHEMATICAL ITALIC SMALL P (0x1d45d)
    case L'𝑞':     // MATHEMATICAL ITALIC SMALL Q (0x1d45e)
    case L'𝑟':     // MATHEMATICAL ITALIC SMALL R (0x1d45f)
    case L'𝑠':     // MATHEMATICAL ITALIC SMALL S (0x1d460)
    case L'𝑡':     // MATHEMATICAL ITALIC SMALL T (0x1d461)
    case L'𝑢':     // MATHEMATICAL ITALIC SMALL U (0x1d462)
    case L'𝑣':     // MATHEMATICAL ITALIC SMALL V (0x1d463)
    case L'𝑤':     // MATHEMATICAL ITALIC SMALL W (0x1d464)
    case L'𝑥':     // MATHEMATICAL ITALIC SMALL X (0x1d465)
    case L'𝑦':     // MATHEMATICAL ITALIC SMALL Y (0x1d466)
    case L'𝑧':     // MATHEMATICAL ITALIC SMALL Z (0x1d467)
    case L'𝒂':     // MATHEMATICAL BOLD ITALIC SMALL A (0x1d482)
    case L'𝒃':     // MATHEMATICAL BOLD ITALIC SMALL B (0x1d483)
    case L'𝒄':     // MATHEMATICAL BOLD ITALIC SMALL C (0x1d484)
    case L'𝒅':     // MATHEMATICAL BOLD ITALIC SMALL D (0x1d485)
    case L'𝒆':     // MATHEMATICAL BOLD ITALIC SMALL E (0x1d486)
    case L'𝒇':     // MATHEMATICAL BOLD ITALIC SMALL F (0x1d487)
    case L'𝒈':     // MATHEMATICAL BOLD ITALIC SMALL G (0x1d488)
    case L'𝒉':     // MATHEMATICAL BOLD ITALIC SMALL H (0x1d489)
    case L'𝒊':     // MATHEMATICAL BOLD ITALIC SMALL I (0x1d48a)
    case L'𝒋':     // MATHEMATICAL BOLD ITALIC SMALL J (0x1d48b)
    case L'𝒌':     // MATHEMATICAL BOLD ITALIC SMALL K (0x1d48c)
    case L'𝒍':     // MATHEMATICAL BOLD ITALIC SMALL L (0x1d48d)
    case L'𝒎':     // MATHEMATICAL BOLD ITALIC SMALL M (0x1d48e)
    case L'𝒏':     // MATHEMATICAL BOLD ITALIC SMALL N (0x1d48f)
    case L'𝒐':     // MATHEMATICAL BOLD ITALIC SMALL O (0x1d490)
    case L'𝒑':     // MATHEMATICAL BOLD ITALIC SMALL P (0x1d491)
    case L'𝒒':     // MATHEMATICAL BOLD ITALIC SMALL Q (0x1d492)
    case L'𝒓':     // MATHEMATICAL BOLD ITALIC SMALL R (0x1d493)
    case L'𝒔':     // MATHEMATICAL BOLD ITALIC SMALL S (0x1d494)
    case L'𝒕':     // MATHEMATICAL BOLD ITALIC SMALL T (0x1d495)
    case L'𝒖':     // MATHEMATICAL BOLD ITALIC SMALL U (0x1d496)
    case L'𝒗':     // MATHEMATICAL BOLD ITALIC SMALL V (0x1d497)
    case L'𝒘':     // MATHEMATICAL BOLD ITALIC SMALL W (0x1d498)
    case L'𝒙':     // MATHEMATICAL BOLD ITALIC SMALL X (0x1d499)
    case L'𝒚':     // MATHEMATICAL BOLD ITALIC SMALL Y (0x1d49a)
    case L'𝒛':     // MATHEMATICAL BOLD ITALIC SMALL Z (0x1d49b)
    case L'𝒶':     // MATHEMATICAL SCRIPT SMALL A (0x1d4b6)
    case L'𝒷':     // MATHEMATICAL SCRIPT SMALL B (0x1d4b7)
    case L'𝒸':     // MATHEMATICAL SCRIPT SMALL C (0x1d4b8)
    case L'𝒹':     // MATHEMATICAL SCRIPT SMALL D (0x1d4b9)
    case L'𝒻':     // MATHEMATICAL SCRIPT SMALL F (0x1d4bb)
    case L'𝒽':     // MATHEMATICAL SCRIPT SMALL H (0x1d4bd)
    case L'𝒾':     // MATHEMATICAL SCRIPT SMALL I (0x1d4be)
    case L'𝒿':     // MATHEMATICAL SCRIPT SMALL J (0x1d4bf)
    case L'𝓀':     // MATHEMATICAL SCRIPT SMALL K (0x1d4c0)
    case L'𝓁':     // MATHEMATICAL SCRIPT SMALL L (0x1d4c1)
    case L'𝓂':     // MATHEMATICAL SCRIPT SMALL M (0x1d4c2)
    case L'𝓃':     // MATHEMATICAL SCRIPT SMALL N (0x1d4c3)
    case L'𝓅':     // MATHEMATICAL SCRIPT SMALL P (0x1d4c5)
    case L'𝓆':     // MATHEMATICAL SCRIPT SMALL Q (0x1d4c6)
    case L'𝓇':     // MATHEMATICAL SCRIPT SMALL R (0x1d4c7)
    case L'𝓈':     // MATHEMATICAL SCRIPT SMALL S (0x1d4c8)
    case L'𝓉':     // MATHEMATICAL SCRIPT SMALL T (0x1d4c9)
    case L'𝓊':     // MATHEMATICAL SCRIPT SMALL U (0x1d4ca)
    case L'𝓋':     // MATHEMATICAL SCRIPT SMALL V (0x1d4cb)
    case L'𝓌':     // MATHEMATICAL SCRIPT SMALL W (0x1d4cc)
    case L'𝓍':     // MATHEMATICAL SCRIPT SMALL X (0x1d4cd)
    case L'𝓎':     // MATHEMATICAL SCRIPT SMALL Y (0x1d4ce)
    case L'𝓏':     // MATHEMATICAL SCRIPT SMALL Z (0x1d4cf)
    case L'𝓪':     // MATHEMATICAL BOLD SCRIPT SMALL A (0x1d4ea)
    case L'𝓫':     // MATHEMATICAL BOLD SCRIPT SMALL B (0x1d4eb)
    case L'𝓬':     // MATHEMATICAL BOLD SCRIPT SMALL C (0x1d4ec)
    case L'𝓭':     // MATHEMATICAL BOLD SCRIPT SMALL D (0x1d4ed)
    case L'𝓮':     // MATHEMATICAL BOLD SCRIPT SMALL E (0x1d4ee)
    case L'𝓯':     // MATHEMATICAL BOLD SCRIPT SMALL F (0x1d4ef)
    case L'𝓰':     // MATHEMATICAL BOLD SCRIPT SMALL G (0x1d4f0)
    case L'𝓱':     // MATHEMATICAL BOLD SCRIPT SMALL H (0x1d4f1)
    case L'𝓲':     // MATHEMATICAL BOLD SCRIPT SMALL I (0x1d4f2)
    case L'𝓳':     // MATHEMATICAL BOLD SCRIPT SMALL J (0x1d4f3)
    case L'𝓴':     // MATHEMATICAL BOLD SCRIPT SMALL K (0x1d4f4)
    case L'𝓵':     // MATHEMATICAL BOLD SCRIPT SMALL L (0x1d4f5)
    case L'𝓶':     // MATHEMATICAL BOLD SCRIPT SMALL M (0x1d4f6)
    case L'𝓷':     // MATHEMATICAL BOLD SCRIPT SMALL N (0x1d4f7)
    case L'𝓸':     // MATHEMATICAL BOLD SCRIPT SMALL O (0x1d4f8)
    case L'𝓹':     // MATHEMATICAL BOLD SCRIPT SMALL P (0x1d4f9)
    case L'𝓺':     // MATHEMATICAL BOLD SCRIPT SMALL Q (0x1d4fa)
    case L'𝓻':     // MATHEMATICAL BOLD SCRIPT SMALL R (0x1d4fb)
    case L'𝓼':     // MATHEMATICAL BOLD SCRIPT SMALL S (0x1d4fc)
    case L'𝓽':     // MATHEMATICAL BOLD SCRIPT SMALL T (0x1d4fd)
    case L'𝓾':     // MATHEMATICAL BOLD SCRIPT SMALL U (0x1d4fe)
    case L'𝓿':     // MATHEMATICAL BOLD SCRIPT SMALL V (0x1d4ff)
    case L'𝔀':     // MATHEMATICAL BOLD SCRIPT SMALL W (0x1d500)
    case L'𝔁':     // MATHEMATICAL BOLD SCRIPT SMALL X (0x1d501)
    case L'𝔂':     // MATHEMATICAL BOLD SCRIPT SMALL Y (0x1d502)
    case L'𝔃':     // MATHEMATICAL BOLD SCRIPT SMALL Z (0x1d503)
    case L'𝔞':     // MATHEMATICAL FRAKTUR SMALL A (0x1d51e)
    case L'𝔟':     // MATHEMATICAL FRAKTUR SMALL B (0x1d51f)
    case L'𝔠':     // MATHEMATICAL FRAKTUR SMALL C (0x1d520)
    case L'𝔡':     // MATHEMATICAL FRAKTUR SMALL D (0x1d521)
    case L'𝔢':     // MATHEMATICAL FRAKTUR SMALL E (0x1d522)
    case L'𝔣':     // MATHEMATICAL FRAKTUR SMALL F (0x1d523)
    case L'𝔤':     // MATHEMATICAL FRAKTUR SMALL G (0x1d524)
    case L'𝔥':     // MATHEMATICAL FRAKTUR SMALL H (0x1d525)
    case L'𝔦':     // MATHEMATICAL FRAKTUR SMALL I (0x1d526)
    case L'𝔧':     // MATHEMATICAL FRAKTUR SMALL J (0x1d527)
    case L'𝔨':     // MATHEMATICAL FRAKTUR SMALL K (0x1d528)
    case L'𝔩':     // MATHEMATICAL FRAKTUR SMALL L (0x1d529)
    case L'𝔪':     // MATHEMATICAL FRAKTUR SMALL M (0x1d52a)
    case L'𝔫':     // MATHEMATICAL FRAKTUR SMALL N (0x1d52b)
    case L'𝔬':     // MATHEMATICAL FRAKTUR SMALL O (0x1d52c)
    case L'𝔭':     // MATHEMATICAL FRAKTUR SMALL P (0x1d52d)
    case L'𝔮':     // MATHEMATICAL FRAKTUR SMALL Q (0x1d52e)
    case L'𝔯':     // MATHEMATICAL FRAKTUR SMALL R (0x1d52f)
    case L'𝔰':     // MATHEMATICAL FRAKTUR SMALL S (0x1d530)
    case L'𝔱':     // MATHEMATICAL FRAKTUR SMALL T (0x1d531)
    case L'𝔲':     // MATHEMATICAL FRAKTUR SMALL U (0x1d532)
    case L'𝔳':     // MATHEMATICAL FRAKTUR SMALL V (0x1d533)
    case L'𝔴':     // MATHEMATICAL FRAKTUR SMALL W (0x1d534)
    case L'𝔵':     // MATHEMATICAL FRAKTUR SMALL X (0x1d535)
    case L'𝔶':     // MATHEMATICAL FRAKTUR SMALL Y (0x1d536)
    case L'𝔷':     // MATHEMATICAL FRAKTUR SMALL Z (0x1d537)
    case L'𝕒':     // MATHEMATICAL DOUBLE-STRUCK SMALL A (0x1d552)
    case L'𝕓':     // MATHEMATICAL DOUBLE-STRUCK SMALL B (0x1d553)
    case L'𝕔':     // MATHEMATICAL DOUBLE-STRUCK SMALL C (0x1d554)
    case L'𝕕':     // MATHEMATICAL DOUBLE-STRUCK SMALL D (0x1d555)
    case L'𝕖':     // MATHEMATICAL DOUBLE-STRUCK SMALL E (0x1d556)
    case L'𝕗':     // MATHEMATICAL DOUBLE-STRUCK SMALL F (0x1d557)
    case L'𝕘':     // MATHEMATICAL DOUBLE-STRUCK SMALL G (0x1d558)
    case L'𝕙':     // MATHEMATICAL DOUBLE-STRUCK SMALL H (0x1d559)
    case L'𝕚':     // MATHEMATICAL DOUBLE-STRUCK SMALL I (0x1d55a)
    case L'𝕛':     // MATHEMATICAL DOUBLE-STRUCK SMALL J (0x1d55b)
    case L'𝕜':     // MATHEMATICAL DOUBLE-STRUCK SMALL K (0x1d55c)
    case L'𝕝':     // MATHEMATICAL DOUBLE-STRUCK SMALL L (0x1d55d)
    case L'𝕞':     // MATHEMATICAL DOUBLE-STRUCK SMALL M (0x1d55e)
    case L'𝕟':     // MATHEMATICAL DOUBLE-STRUCK SMALL N (0x1d55f)
    case L'𝕠':     // MATHEMATICAL DOUBLE-STRUCK SMALL O (0x1d560)
    case L'𝕡':     // MATHEMATICAL DOUBLE-STRUCK SMALL P (0x1d561)
    case L'𝕢':     // MATHEMATICAL DOUBLE-STRUCK SMALL Q (0x1d562)
    case L'𝕣':     // MATHEMATICAL DOUBLE-STRUCK SMALL R (0x1d563)
    case L'𝕤':     // MATHEMATICAL DOUBLE-STRUCK SMALL S (0x1d564)
    case L'𝕥':     // MATHEMATICAL DOUBLE-STRUCK SMALL T (0x1d565)
    case L'𝕦':     // MATHEMATICAL DOUBLE-STRUCK SMALL U (0x1d566)
    case L'𝕧':     // MATHEMATICAL DOUBLE-STRUCK SMALL V (0x1d567)
    case L'𝕨':     // MATHEMATICAL DOUBLE-STRUCK SMALL W (0x1d568)
    case L'𝕩':     // MATHEMATICAL DOUBLE-STRUCK SMALL X (0x1d569)
    case L'𝕪':     // MATHEMATICAL DOUBLE-STRUCK SMALL Y (0x1d56a)
    case L'𝕫':     // MATHEMATICAL DOUBLE-STRUCK SMALL Z (0x1d56b)
    case L'𝖆':     // MATHEMATICAL BOLD FRAKTUR SMALL A (0x1d586)
    case L'𝖇':     // MATHEMATICAL BOLD FRAKTUR SMALL B (0x1d587)
    case L'𝖈':     // MATHEMATICAL BOLD FRAKTUR SMALL C (0x1d588)
    case L'𝖉':     // MATHEMATICAL BOLD FRAKTUR SMALL D (0x1d589)
    case L'𝖊':     // MATHEMATICAL BOLD FRAKTUR SMALL E (0x1d58a)
    case L'𝖋':     // MATHEMATICAL BOLD FRAKTUR SMALL F (0x1d58b)
    case L'𝖌':     // MATHEMATICAL BOLD FRAKTUR SMALL G (0x1d58c)
    case L'𝖍':     // MATHEMATICAL BOLD FRAKTUR SMALL H (0x1d58d)
    case L'𝖎':     // MATHEMATICAL BOLD FRAKTUR SMALL I (0x1d58e)
    case L'𝖏':     // MATHEMATICAL BOLD FRAKTUR SMALL J (0x1d58f)
    case L'𝖐':     // MATHEMATICAL BOLD FRAKTUR SMALL K (0x1d590)
    case L'𝖑':     // MATHEMATICAL BOLD FRAKTUR SMALL L (0x1d591)
    case L'𝖒':     // MATHEMATICAL BOLD FRAKTUR SMALL M (0x1d592)
    case L'𝖓':     // MATHEMATICAL BOLD FRAKTUR SMALL N (0x1d593)
    case L'𝖔':     // MATHEMATICAL BOLD FRAKTUR SMALL O (0x1d594)
    case L'𝖕':     // MATHEMATICAL BOLD FRAKTUR SMALL P (0x1d595)
    case L'𝖖':     // MATHEMATICAL BOLD FRAKTUR SMALL Q (0x1d596)
    case L'𝖗':     // MATHEMATICAL BOLD FRAKTUR SMALL R (0x1d597)
    case L'𝖘':     // MATHEMATICAL BOLD FRAKTUR SMALL S (0x1d598)
    case L'𝖙':     // MATHEMATICAL BOLD FRAKTUR SMALL T (0x1d599)
    case L'𝖚':     // MATHEMATICAL BOLD FRAKTUR SMALL U (0x1d59a)
    case L'𝖛':     // MATHEMATICAL BOLD FRAKTUR SMALL V (0x1d59b)
    case L'𝖜':     // MATHEMATICAL BOLD FRAKTUR SMALL W (0x1d59c)
    case L'𝖝':     // MATHEMATICAL BOLD FRAKTUR SMALL X (0x1d59d)
    case L'𝖞':     // MATHEMATICAL BOLD FRAKTUR SMALL Y (0x1d59e)
    case L'𝖟':     // MATHEMATICAL BOLD FRAKTUR SMALL Z (0x1d59f)
    case L'𝖺':     // MATHEMATICAL SANS SMALL A (0x1d5ba)
    case L'𝖻':     // MATHEMATICAL SANS SMALL B (0x1d5bb)
    case L'𝖼':     // MATHEMATICAL SANS SMALL C (0x1d5bc)
    case L'𝖽':     // MATHEMATICAL SANS SMALL D (0x1d5bd)
    case L'𝖾':     // MATHEMATICAL SANS SMALL E (0x1d5be)
    case L'𝖿':     // MATHEMATICAL SANS SMALL F (0x1d5bf)
    case L'𝗀':     // MATHEMATICAL SANS SMALL G (0x1d5c0)
    case L'𝗁':     // MATHEMATICAL SANS SMALL H (0x1d5c1)
    case L'𝗂':     // MATHEMATICAL SANS SMALL I (0x1d5c2)
    case L'𝗃':     // MATHEMATICAL SANS SMALL J (0x1d5c3)
    case L'𝗄':     // MATHEMATICAL SANS SMALL K (0x1d5c4)
    case L'𝗅':     // MATHEMATICAL SANS SMALL L (0x1d5c5)
    case L'𝗆':     // MATHEMATICAL SANS SMALL M (0x1d5c6)
    case L'𝗇':     // MATHEMATICAL SANS SMALL N (0x1d5c7)
    case L'𝗈':     // MATHEMATICAL SANS SMALL O (0x1d5c8)
    case L'𝗉':     // MATHEMATICAL SANS SMALL P (0x1d5c9)
    case L'𝗊':     // MATHEMATICAL SANS SMALL Q (0x1d5ca)
    case L'𝗋':     // MATHEMATICAL SANS SMALL R (0x1d5cb)
    case L'𝗌':     // MATHEMATICAL SANS SMALL S (0x1d5cc)
    case L'𝗍':     // MATHEMATICAL SANS SMALL T (0x1d5cd)
    case L'𝗎':     // MATHEMATICAL SANS SMALL U (0x1d5ce)
    case L'𝗏':     // MATHEMATICAL SANS SMALL V (0x1d5cf)
    case L'𝗐':     // MATHEMATICAL SANS SMALL W (0x1d5d0)
    case L'𝗑':     // MATHEMATICAL SANS SMALL X (0x1d5d1)
    case L'𝗒':     // MATHEMATICAL SANS SMALL Y (0x1d5d2)
    case L'𝗓':     // MATHEMATICAL SANS SMALL Z (0x1d5d3)
    case L'𝗮':     // MATHEMATICAL SANS BOLD SMALL A (0x1d5ee)
    case L'𝗯':     // MATHEMATICAL SANS BOLD SMALL B (0x1d5ef)
    case L'𝗰':     // MATHEMATICAL SANS BOLD SMALL C (0x1d5f0)
    case L'𝗱':     // MATHEMATICAL SANS BOLD SMALL D (0x1d5f1)
    case L'𝗲':     // MATHEMATICAL SANS BOLD SMALL E (0x1d5f2)
    case L'𝗳':     // MATHEMATICAL SANS BOLD SMALL F (0x1d5f3)
    case L'𝗴':     // MATHEMATICAL SANS BOLD SMALL G (0x1d5f4)
    case L'𝗵':     // MATHEMATICAL SANS BOLD SMALL H (0x1d5f5)
    case L'𝗶':     // MATHEMATICAL SANS BOLD SMALL I (0x1d5f6)
    case L'𝗷':     // MATHEMATICAL SANS BOLD SMALL J (0x1d5f7)
    case L'𝗸':     // MATHEMATICAL SANS BOLD SMALL K (0x1d5f8)
    case L'𝗹':     // MATHEMATICAL SANS BOLD SMALL L (0x1d5f9)
    case L'𝗺':     // MATHEMATICAL SANS BOLD SMALL M (0x1d5fa)
    case L'𝗻':     // MATHEMATICAL SANS BOLD SMALL N (0x1d5fb)
    case L'𝗼':     // MATHEMATICAL SANS BOLD SMALL O (0x1d5fc)
    case L'𝗽':     // MATHEMATICAL SANS BOLD SMALL P (0x1d5fd)
    case L'𝗾':     // MATHEMATICAL SANS BOLD SMALL Q (0x1d5fe)
    case L'𝗿':     // MATHEMATICAL SANS BOLD SMALL R (0x1d5ff)
    case L'𝘀':     // MATHEMATICAL SANS BOLD SMALL S (0x1d600)
    case L'𝘁':     // MATHEMATICAL SANS BOLD SMALL T (0x1d601)
    case L'𝘂':     // MATHEMATICAL SANS BOLD SMALL U (0x1d602)
    case L'𝘃':     // MATHEMATICAL SANS BOLD SMALL V (0x1d603)
    case L'𝘄':     // MATHEMATICAL SANS BOLD SMALL W (0x1d604)
    case L'𝘅':     // MATHEMATICAL SANS BOLD SMALL X (0x1d605)
    case L'𝘆':     // MATHEMATICAL SANS BOLD SMALL Y (0x1d606)
    case L'𝘇':     // MATHEMATICAL SANS BOLD SMALL Z (0x1d607)
    case L'𝘢':     // MATHEMATICAL SANS ITALIC SMALL A (0x1d622)
    case L'𝘣':     // MATHEMATICAL SANS ITALIC SMALL B (0x1d623)
    case L'𝘤':     // MATHEMATICAL SANS ITALIC SMALL C (0x1d624)
    case L'𝘥':     // MATHEMATICAL SANS ITALIC SMALL D (0x1d625)
    case L'𝘦':     // MATHEMATICAL SANS ITALIC SMALL E (0x1d626)
    case L'𝘧':     // MATHEMATICAL SANS ITALIC SMALL F (0x1d627)
    case L'𝘨':     // MATHEMATICAL SANS ITALIC SMALL G (0x1d628)
    case L'𝘩':     // MATHEMATICAL SANS ITALIC SMALL H (0x1d629)
    case L'𝘪':     // MATHEMATICAL SANS ITALIC SMALL I (0x1d62a)
    case L'𝘫':     // MATHEMATICAL SANS ITALIC SMALL J (0x1d62b)
    case L'𝘬':     // MATHEMATICAL SANS ITALIC SMALL K (0x1d62c)
    case L'𝘭':     // MATHEMATICAL SANS ITALIC SMALL L (0x1d62d)
    case L'𝘮':     // MATHEMATICAL SANS ITALIC SMALL M (0x1d62e)
    case L'𝘯':     // MATHEMATICAL SANS ITALIC SMALL N (0x1d62f)
    case L'𝘰':     // MATHEMATICAL SANS ITALIC SMALL O (0x1d630)
    case L'𝘱':     // MATHEMATICAL SANS ITALIC SMALL P (0x1d631)
    case L'𝘲':     // MATHEMATICAL SANS ITALIC SMALL Q (0x1d632)
    case L'𝘳':     // MATHEMATICAL SANS ITALIC SMALL R (0x1d633)
    case L'𝘴':     // MATHEMATICAL SANS ITALIC SMALL S (0x1d634)
    case L'𝘵':     // MATHEMATICAL SANS ITALIC SMALL T (0x1d635)
    case L'𝘶':     // MATHEMATICAL SANS ITALIC SMALL U (0x1d636)
    case L'𝘷':     // MATHEMATICAL SANS ITALIC SMALL V (0x1d637)
    case L'𝘸':     // MATHEMATICAL SANS ITALIC SMALL W (0x1d638)
    case L'𝘹':     // MATHEMATICAL SANS ITALIC SMALL X (0x1d639)
    case L'𝘺':     // MATHEMATICAL SANS ITALIC SMALL Y (0x1d63a)
    case L'𝘻':     // MATHEMATICAL SANS ITALIC SMALL Z (0x1d63b)
    case L'𝙖':     // MATHEMATICAL SANS BOLD ITALIC SMALL A (0x1d656)
    case L'𝙗':     // MATHEMATICAL SANS BOLD ITALIC SMALL B (0x1d657)
    case L'𝙘':     // MATHEMATICAL SANS BOLD ITALIC SMALL C (0x1d658)
    case L'𝙙':     // MATHEMATICAL SANS BOLD ITALIC SMALL D (0x1d659)
    case L'𝙚':     // MATHEMATICAL SANS BOLD ITALIC SMALL E (0x1d65a)
    case L'𝙛':     // MATHEMATICAL SANS BOLD ITALIC SMALL F (0x1d65b)
    case L'𝙜':     // MATHEMATICAL SANS BOLD ITALIC SMALL G (0x1d65c)
    case L'𝙝':     // MATHEMATICAL SANS BOLD ITALIC SMALL H (0x1d65d)
    case L'𝙞':     // MATHEMATICAL SANS BOLD ITALIC SMALL I (0x1d65e)
    case L'𝙟':     // MATHEMATICAL SANS BOLD ITALIC SMALL J (0x1d65f)
    case L'𝙠':     // MATHEMATICAL SANS BOLD ITALIC SMALL K (0x1d660)
    case L'𝙡':     // MATHEMATICAL SANS BOLD ITALIC SMALL L (0x1d661)
    case L'𝙢':     // MATHEMATICAL SANS BOLD ITALIC SMALL M (0x1d662)
    case L'𝙣':     // MATHEMATICAL SANS BOLD ITALIC SMALL N (0x1d663)
    case L'𝙤':     // MATHEMATICAL SANS BOLD ITALIC SMALL O (0x1d664)
    case L'𝙥':     // MATHEMATICAL SANS BOLD ITALIC SMALL P (0x1d665)
    case L'𝙦':     // MATHEMATICAL SANS BOLD ITALIC SMALL Q (0x1d666)
    case L'𝙧':     // MATHEMATICAL SANS BOLD ITALIC SMALL R (0x1d667)
    case L'𝙨':     // MATHEMATICAL SANS BOLD ITALIC SMALL S (0x1d668)
    case L'𝙩':     // MATHEMATICAL SANS BOLD ITALIC SMALL T (0x1d669)
    case L'𝙪':     // MATHEMATICAL SANS BOLD ITALIC SMALL U (0x1d66a)
    case L'𝙫':     // MATHEMATICAL SANS BOLD ITALIC SMALL V (0x1d66b)
    case L'𝙬':     // MATHEMATICAL SANS BOLD ITALIC SMALL W (0x1d66c)
    case L'𝙭':     // MATHEMATICAL SANS BOLD ITALIC SMALL X (0x1d66d)
    case L'𝙮':     // MATHEMATICAL SANS BOLD ITALIC SMALL Y (0x1d66e)
    case L'𝙯':     // MATHEMATICAL SANS BOLD ITALIC SMALL Z (0x1d66f)
    case L'𝚊':     // MATHEMATICAL MONOSPACE SMALL A (0x1d68a)
    case L'𝚋':     // MATHEMATICAL MONOSPACE SMALL B (0x1d68b)
    case L'𝚌':     // MATHEMATICAL MONOSPACE SMALL C (0x1d68c)
    case L'𝚍':     // MATHEMATICAL MONOSPACE SMALL D (0x1d68d)
    case L'𝚎':     // MATHEMATICAL MONOSPACE SMALL E (0x1d68e)
    case L'𝚏':     // MATHEMATICAL MONOSPACE SMALL F (0x1d68f)
    case L'𝚐':     // MATHEMATICAL MONOSPACE SMALL G (0x1d690)
    case L'𝚑':     // MATHEMATICAL MONOSPACE SMALL H (0x1d691)
    case L'𝚒':     // MATHEMATICAL MONOSPACE SMALL I (0x1d692)
    case L'𝚓':     // MATHEMATICAL MONOSPACE SMALL J (0x1d693)
    case L'𝚔':     // MATHEMATICAL MONOSPACE SMALL K (0x1d694)
    case L'𝚕':     // MATHEMATICAL MONOSPACE SMALL L (0x1d695)
    case L'𝚖':     // MATHEMATICAL MONOSPACE SMALL M (0x1d696)
    case L'𝚗':     // MATHEMATICAL MONOSPACE SMALL N (0x1d697)
    case L'𝚘':     // MATHEMATICAL MONOSPACE SMALL O (0x1d698)
    case L'𝚙':     // MATHEMATICAL MONOSPACE SMALL P (0x1d699)
    case L'𝚚':     // MATHEMATICAL MONOSPACE SMALL Q (0x1d69a)
    case L'𝚛':     // MATHEMATICAL MONOSPACE SMALL R (0x1d69b)
    case L'𝚜':     // MATHEMATICAL MONOSPACE SMALL S (0x1d69c)
    case L'𝚝':     // MATHEMATICAL MONOSPACE SMALL T (0x1d69d)
    case L'𝚞':     // MATHEMATICAL MONOSPACE SMALL U (0x1d69e)
    case L'𝚟':     // MATHEMATICAL MONOSPACE SMALL V (0x1d69f)
    case L'𝚠':     // MATHEMATICAL MONOSPACE SMALL W (0x1d6a0)
    case L'𝚡':     // MATHEMATICAL MONOSPACE SMALL X (0x1d6a1)
    case L'𝚢':     // MATHEMATICAL MONOSPACE SMALL Y (0x1d6a2)
    case L'𝚣':     // MATHEMATICAL MONOSPACE SMALL Z (0x1d6a3)
    case L'𝚤':     // MATHEMATICAL ITALIC SMALL DOTLESS I (0x1d6a4)
    case L'𝚥':     // MATHEMATICAL ITALIC SMALL DOTLESS J (0x1d6a5)
    case L'𝛂':     // MATHEMATICAL BOLD SMALL ALPHA (0x1d6c2)
    case L'𝛃':     // MATHEMATICAL BOLD SMALL BETA (0x1d6c3)
    case L'𝛄':     // MATHEMATICAL BOLD SMALL GAMMA (0x1d6c4)
    case L'𝛅':     // MATHEMATICAL BOLD SMALL DELTA (0x1d6c5)
    case L'𝛆':     // MATHEMATICAL BOLD SMALL EPSILON (0x1d6c6)
    case L'𝛇':     // MATHEMATICAL BOLD SMALL ZETA (0x1d6c7)
    case L'𝛈':     // MATHEMATICAL BOLD SMALL ETA (0x1d6c8)
    case L'𝛉':     // MATHEMATICAL BOLD SMALL THETA (0x1d6c9)
    case L'𝛊':     // MATHEMATICAL BOLD SMALL IOTA (0x1d6ca)
    case L'𝛋':     // MATHEMATICAL BOLD SMALL KAPPA (0x1d6cb)
    case L'𝛌':     // MATHEMATICAL BOLD SMALL LAMDA (0x1d6cc)
    case L'𝛍':     // MATHEMATICAL BOLD SMALL MU (0x1d6cd)
    case L'𝛎':     // MATHEMATICAL BOLD SMALL NU (0x1d6ce)
    case L'𝛏':     // MATHEMATICAL BOLD SMALL XI (0x1d6cf)
    case L'𝛐':     // MATHEMATICAL BOLD SMALL OMICRON (0x1d6d0)
    case L'𝛑':     // MATHEMATICAL BOLD SMALL PI (0x1d6d1)
    case L'𝛒':     // MATHEMATICAL BOLD SMALL RHO (0x1d6d2)
    case L'𝛓':     // MATHEMATICAL BOLD SMALL FINAL SIGMA (0x1d6d3)
    case L'𝛔':     // MATHEMATICAL BOLD SMALL SIGMA (0x1d6d4)
    case L'𝛕':     // MATHEMATICAL BOLD SMALL TAU (0x1d6d5)
    case L'𝛖':     // MATHEMATICAL BOLD SMALL UPSILON (0x1d6d6)
    case L'𝛗':     // MATHEMATICAL BOLD SMALL PHI (0x1d6d7)
    case L'𝛘':     // MATHEMATICAL BOLD SMALL CHI (0x1d6d8)
    case L'𝛙':     // MATHEMATICAL BOLD SMALL PSI (0x1d6d9)
    case L'𝛚':     // MATHEMATICAL BOLD SMALL OMEGA (0x1d6da)
    case L'𝛜':     // MATHEMATICAL BOLD EPSILON SYMBOL (0x1d6dc)
    case L'𝛝':     // MATHEMATICAL BOLD THETA SYMBOL (0x1d6dd)
    case L'𝛞':     // MATHEMATICAL BOLD KAPPA SYMBOL (0x1d6de)
    case L'𝛟':     // MATHEMATICAL BOLD PHI SYMBOL (0x1d6df)
    case L'𝛠':     // MATHEMATICAL BOLD RHO SYMBOL (0x1d6e0)
    case L'𝛡':     // MATHEMATICAL BOLD PI SYMBOL (0x1d6e1)
    case L'𝛼':     // MATHEMATICAL ITALIC SMALL ALPHA (0x1d6fc)
    case L'𝛽':     // MATHEMATICAL ITALIC SMALL BETA (0x1d6fd)
    case L'𝛾':     // MATHEMATICAL ITALIC SMALL GAMMA (0x1d6fe)
    case L'𝛿':     // MATHEMATICAL ITALIC SMALL DELTA (0x1d6ff)
    case L'𝜀':     // MATHEMATICAL ITALIC SMALL EPSILON (0x1d700)
    case L'𝜁':     // MATHEMATICAL ITALIC SMALL ZETA (0x1d701)
    case L'𝜂':     // MATHEMATICAL ITALIC SMALL ETA (0x1d702)
    case L'𝜃':     // MATHEMATICAL ITALIC SMALL THETA (0x1d703)
    case L'𝜄':     // MATHEMATICAL ITALIC SMALL IOTA (0x1d704)
    case L'𝜅':     // MATHEMATICAL ITALIC SMALL KAPPA (0x1d705)
    case L'𝜆':     // MATHEMATICAL ITALIC SMALL LAMDA (0x1d706)
    case L'𝜇':     // MATHEMATICAL ITALIC SMALL MU (0x1d707)
    case L'𝜈':     // MATHEMATICAL ITALIC SMALL NU (0x1d708)
    case L'𝜉':     // MATHEMATICAL ITALIC SMALL XI (0x1d709)
    case L'𝜊':     // MATHEMATICAL ITALIC SMALL OMICRON (0x1d70a)
    case L'𝜋':     // MATHEMATICAL ITALIC SMALL PI (0x1d70b)
    case L'𝜌':     // MATHEMATICAL ITALIC SMALL RHO (0x1d70c)
    case L'𝜍':     // MATHEMATICAL ITALIC SMALL FINAL SIGMA (0x1d70d)
    case L'𝜎':     // MATHEMATICAL ITALIC SMALL SIGMA (0x1d70e)
    case L'𝜏':     // MATHEMATICAL ITALIC SMALL TAU (0x1d70f)
    case L'𝜐':     // MATHEMATICAL ITALIC SMALL UPSILON (0x1d710)
    case L'𝜑':     // MATHEMATICAL ITALIC SMALL PHI (0x1d711)
    case L'𝜒':     // MATHEMATICAL ITALIC SMALL CHI (0x1d712)
    case L'𝜓':     // MATHEMATICAL ITALIC SMALL PSI (0x1d713)
    case L'𝜔':     // MATHEMATICAL ITALIC SMALL OMEGA (0x1d714)
    case L'𝜖':     // MATHEMATICAL ITALIC EPSILON SYMBOL (0x1d716)
    case L'𝜗':     // MATHEMATICAL ITALIC THETA SYMBOL (0x1d717)
    case L'𝜘':     // MATHEMATICAL ITALIC KAPPA SYMBOL (0x1d718)
    case L'𝜙':     // MATHEMATICAL ITALIC PHI SYMBOL (0x1d719)
    case L'𝜚':     // MATHEMATICAL ITALIC RHO SYMBOL (0x1d71a)
    case L'𝜛':     // MATHEMATICAL ITALIC PI SYMBOL (0x1d71b)
    case L'𝜶':     // MATHEMATICAL BOLD ITALIC SMALL ALPHA (0x1d736)
    case L'𝜷':     // MATHEMATICAL BOLD ITALIC SMALL BETA (0x1d737)
    case L'𝜸':     // MATHEMATICAL BOLD ITALIC SMALL GAMMA (0x1d738)
    case L'𝜹':     // MATHEMATICAL BOLD ITALIC SMALL DELTA (0x1d739)
    case L'𝜺':     // MATHEMATICAL BOLD ITALIC SMALL EPSILON (0x1d73a)
    case L'𝜻':     // MATHEMATICAL BOLD ITALIC SMALL ZETA (0x1d73b)
    case L'𝜼':     // MATHEMATICAL BOLD ITALIC SMALL ETA (0x1d73c)
    case L'𝜽':     // MATHEMATICAL BOLD ITALIC SMALL THETA (0x1d73d)
    case L'𝜾':     // MATHEMATICAL BOLD ITALIC SMALL IOTA (0x1d73e)
    case L'𝜿':     // MATHEMATICAL BOLD ITALIC SMALL KAPPA (0x1d73f)
    case L'𝝀':     // MATHEMATICAL BOLD ITALIC SMALL LAMDA (0x1d740)
    case L'𝝁':     // MATHEMATICAL BOLD ITALIC SMALL MU (0x1d741)
    case L'𝝂':     // MATHEMATICAL BOLD ITALIC SMALL NU (0x1d742)
    case L'𝝃':     // MATHEMATICAL BOLD ITALIC SMALL XI (0x1d743)
    case L'𝝄':     // MATHEMATICAL BOLD ITALIC SMALL OMICRON (0x1d744)
    case L'𝝅':     // MATHEMATICAL BOLD ITALIC SMALL PI (0x1d745)
    case L'𝝆':     // MATHEMATICAL BOLD ITALIC SMALL RHO (0x1d746)
    case L'𝝇':     // MATHEMATICAL BOLD ITALIC SMALL FINAL SIGMA (0x1d747)
    case L'𝝈':     // MATHEMATICAL BOLD ITALIC SMALL SIGMA (0x1d748)
    case L'𝝉':     // MATHEMATICAL BOLD ITALIC SMALL TAU (0x1d749)
    case L'𝝊':     // MATHEMATICAL BOLD ITALIC SMALL UPSILON (0x1d74a)
    case L'𝝋':     // MATHEMATICAL BOLD ITALIC SMALL PHI (0x1d74b)
    case L'𝝌':     // MATHEMATICAL BOLD ITALIC SMALL CHI (0x1d74c)
    case L'𝝍':     // MATHEMATICAL BOLD ITALIC SMALL PSI (0x1d74d)
    case L'𝝎':     // MATHEMATICAL BOLD ITALIC SMALL OMEGA (0x1d74e)
    case L'𝝐':     // MATHEMATICAL BOLD ITALIC EPSILON SYMBOL (0x1d750)
    case L'𝝑':     // MATHEMATICAL BOLD ITALIC THETA SYMBOL (0x1d751)
    case L'𝝒':     // MATHEMATICAL BOLD ITALIC KAPPA SYMBOL (0x1d752)
    case L'𝝓':     // MATHEMATICAL BOLD ITALIC PHI SYMBOL (0x1d753)
    case L'𝝔':     // MATHEMATICAL BOLD ITALIC RHO SYMBOL (0x1d754)
    case L'𝝕':     // MATHEMATICAL BOLD ITALIC PI SYMBOL (0x1d755)
    case L'𝝰':     // MATHEMATICAL SANS BOLD SMALL ALPHA (0x1d770)
    case L'𝝱':     // MATHEMATICAL SANS BOLD SMALL BETA (0x1d771)
    case L'𝝲':     // MATHEMATICAL SANS BOLD SMALL GAMMA (0x1d772)
    case L'𝝳':     // MATHEMATICAL SANS BOLD SMALL DELTA (0x1d773)
    case L'𝝴':     // MATHEMATICAL SANS BOLD SMALL EPSILON (0x1d774)
    case L'𝝵':     // MATHEMATICAL SANS BOLD SMALL ZETA (0x1d775)
    case L'𝝶':     // MATHEMATICAL SANS BOLD SMALL ETA (0x1d776)
    case L'𝝷':     // MATHEMATICAL SANS BOLD SMALL THETA (0x1d777)
    case L'𝝸':     // MATHEMATICAL SANS BOLD SMALL IOTA (0x1d778)
    case L'𝝹':     // MATHEMATICAL SANS BOLD SMALL KAPPA (0x1d779)
    case L'𝝺':     // MATHEMATICAL SANS BOLD SMALL LAMDA (0x1d77a)
    case L'𝝻':     // MATHEMATICAL SANS BOLD SMALL MU (0x1d77b)
    case L'𝝼':     // MATHEMATICAL SANS BOLD SMALL NU (0x1d77c)
    case L'𝝽':     // MATHEMATICAL SANS BOLD SMALL XI (0x1d77d)
    case L'𝝾':     // MATHEMATICAL SANS BOLD SMALL OMICRON (0x1d77e)
    case L'𝝿':     // MATHEMATICAL SANS BOLD SMALL PI (0x1d77f)
    case L'𝞀':     // MATHEMATICAL SANS BOLD SMALL RHO (0x1d780)
    case L'𝞁':     // MATHEMATICAL SANS BOLD SMALL FINAL SIGMA (0x1d781)
    case L'𝞂':     // MATHEMATICAL SANS BOLD SMALL SIGMA (0x1d782)
    case L'𝞃':     // MATHEMATICAL SANS BOLD SMALL TAU (0x1d783)
    case L'𝞄':     // MATHEMATICAL SANS BOLD SMALL UPSILON (0x1d784)
    case L'𝞅':     // MATHEMATICAL SANS BOLD SMALL PHI (0x1d785)
    case L'𝞆':     // MATHEMATICAL SANS BOLD SMALL CHI (0x1d786)
    case L'𝞇':     // MATHEMATICAL SANS BOLD SMALL PSI (0x1d787)
    case L'𝞈':     // MATHEMATICAL SANS BOLD SMALL OMEGA (0x1d788)
    case L'𝞊':     // MATHEMATICAL SANS BOLD EPSILON SYMBOL (0x1d78a)
    case L'𝞋':     // MATHEMATICAL SANS BOLD THETA SYMBOL (0x1d78b)
    case L'𝞌':     // MATHEMATICAL SANS BOLD KAPPA SYMBOL (0x1d78c)
    case L'𝞍':     // MATHEMATICAL SANS BOLD PHI SYMBOL (0x1d78d)
    case L'𝞎':     // MATHEMATICAL SANS BOLD RHO SYMBOL (0x1d78e)
    case L'𝞏':     // MATHEMATICAL SANS BOLD PI SYMBOL (0x1d78f)
    case L'𝞪':     // MATHEMATICAL SANS BOLD ITALIC SMALL ALPHA (0x1d7aa)
    case L'𝞫':     // MATHEMATICAL SANS BOLD ITALIC SMALL BETA (0x1d7ab)
    case L'𝞬':     // MATHEMATICAL SANS BOLD ITALIC SMALL GAMMA (0x1d7ac)
    case L'𝞭':     // MATHEMATICAL SANS BOLD ITALIC SMALL DELTA (0x1d7ad)
    case L'𝞮':     // MATHEMATICAL SANS BOLD ITALIC SMALL EPSILON (0x1d7ae)
    case L'𝞯':     // MATHEMATICAL SANS BOLD ITALIC SMALL ZETA (0x1d7af)
    case L'𝞰':     // MATHEMATICAL SANS BOLD ITALIC SMALL ETA (0x1d7b0)
    case L'𝞱':     // MATHEMATICAL SANS BOLD ITALIC SMALL THETA (0x1d7b1)
    case L'𝞲':     // MATHEMATICAL SANS BOLD ITALIC SMALL IOTA (0x1d7b2)
    case L'𝞳':     // MATHEMATICAL SANS BOLD ITALIC SMALL KAPPA (0x1d7b3)
    case L'𝞴':     // MATHEMATICAL SANS BOLD ITALIC SMALL LAMDA (0x1d7b4)
    case L'𝞵':     // MATHEMATICAL SANS BOLD ITALIC SMALL MU (0x1d7b5)
    case L'𝞶':     // MATHEMATICAL SANS BOLD ITALIC SMALL NU (0x1d7b6)
    case L'𝞷':     // MATHEMATICAL SANS BOLD ITALIC SMALL XI (0x1d7b7)
    case L'𝞸':     // MATHEMATICAL SANS BOLD ITALIC SMALL OMICRON (0x1d7b8)
    case L'𝞹':     // MATHEMATICAL SANS BOLD ITALIC SMALL PI (0x1d7b9)
    case L'𝞺':     // MATHEMATICAL SANS BOLD ITALIC SMALL RHO (0x1d7ba)
    case L'𝞻':     // MATHEMATICAL SANS BOLD ITALIC SMALL FINAL SIGMA (0x1d7bb)
    case L'𝞼':     // MATHEMATICAL SANS BOLD ITALIC SMALL SIGMA (0x1d7bc)
    case L'𝞽':     // MATHEMATICAL SANS BOLD ITALIC SMALL TAU (0x1d7bd)
    case L'𝞾':     // MATHEMATICAL SANS BOLD ITALIC SMALL UPSILON (0x1d7be)
    case L'𝞿':     // MATHEMATICAL SANS BOLD ITALIC SMALL PHI (0x1d7bf)
    case L'𝟀':     // MATHEMATICAL SANS BOLD ITALIC SMALL CHI (0x1d7c0)
    case L'𝟁':     // MATHEMATICAL SANS BOLD ITALIC SMALL PSI (0x1d7c1)
    case L'𝟂':     // MATHEMATICAL SANS BOLD ITALIC SMALL OMEGA (0x1d7c2)
    case L'𝟄':     // MATHEMATICAL SANS BOLD ITALIC EPSILON SYMBOL (0x1d7c4)
    case L'𝟅':     // MATHEMATICAL SANS BOLD ITALIC THETA SYMBOL (0x1d7c5)
    case L'𝟆':     // MATHEMATICAL SANS BOLD ITALIC KAPPA SYMBOL (0x1d7c6)
    case L'𝟇':     // MATHEMATICAL SANS BOLD ITALIC PHI SYMBOL (0x1d7c7)
    case L'𝟈':     // MATHEMATICAL SANS BOLD ITALIC RHO SYMBOL (0x1d7c8)
    case L'𝟉':     // MATHEMATICAL SANS BOLD ITALIC PI SYMBOL (0x1d7c9)
    case L'𝟋':     // MATHEMATICAL BOLD SMALL DIGAMMA (0x1d7cb)
    case L'𞤢':  // ADLAM SMALL ALIF (0x1e922)
    case L'𞤣':  // ADLAM SMALL DAALI (0x1e923)
    case L'𞤤':  // ADLAM SMALL LAAM (0x1e924)
    case L'𞤥':  // ADLAM SMALL MIIM (0x1e925)
    case L'𞤦':  // ADLAM SMALL BA (0x1e926)
    case L'𞤧':  // ADLAM SMALL SINNYIIYHE (0x1e927)
    case L'𞤨':  // ADLAM SMALL PE (0x1e928)
    case L'𞤩':  // ADLAM SMALL BHE (0x1e929)
    case L'𞤪':  // ADLAM SMALL RA (0x1e92a)
    case L'𞤫':  // ADLAM SMALL E (0x1e92b)
    case L'𞤬':  // ADLAM SMALL FA (0x1e92c)
    case L'𞤭':  // ADLAM SMALL I (0x1e92d)
    case L'𞤮':  // ADLAM SMALL O (0x1e92e)
    case L'𞤯':  // ADLAM SMALL DHA (0x1e92f)
    case L'𞤰':  // ADLAM SMALL YHE (0x1e930)
    case L'𞤱':  // ADLAM SMALL WAW (0x1e931)
    case L'𞤲':  // ADLAM SMALL NUN (0x1e932)
    case L'𞤳':  // ADLAM SMALL KAF (0x1e933)
    case L'𞤴':  // ADLAM SMALL YA (0x1e934)
    case L'𞤵':  // ADLAM SMALL U (0x1e935)
    case L'𞤶':  // ADLAM SMALL JIIM (0x1e936)
    case L'𞤷':  // ADLAM SMALL CHI (0x1e937)
    case L'𞤸':  // ADLAM SMALL HA (0x1e938)
    case L'𞤹':  // ADLAM SMALL QAAF (0x1e939)
    case L'𞤺':  // ADLAM SMALL GA (0x1e93a)
    case L'𞤻':  // ADLAM SMALL NYA (0x1e93b)
    case L'𞤼':  // ADLAM SMALL TU (0x1e93c)
    case L'𞤽':  // ADLAM SMALL NHA (0x1e93d)
    case L'𞤾':  // ADLAM SMALL VA (0x1e93e)
    case L'𞤿':  // ADLAM SMALL KHA (0x1e93f)
    case L'𞥀':  // ADLAM SMALL GBE (0x1e940)
    case L'𞥁':  // ADLAM SMALL ZAL (0x1e941)
    case L'𞥂':  // ADLAM SMALL KPO (0x1e942)
    case L'𞥃':  // ADLAM SMALL SHA (0x1e943)
      return 1;
    default:
      return 0;
  }
}
